<?php

/**
 * Show Coupon box
 * Class VI_WOOCOMMERCE_COUPON_BOX_Frontend_Coupon
 *
 */
class VI_WOOCOMMERCE_COUPON_BOX_Frontend_Frontend {
	protected $settings;
	protected $existing_coupons;
	protected $characters_array;
	protected $language;
	protected $language_ajax;

	public function __construct() {
		$this->settings      = new VI_WOOCOMMERCE_COUPON_BOX_DATA();
		$this->language      = '';
		$this->language_ajax = '';
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
		/*Ajax add email*/
		if ( $this->settings->get_params( 'ajax_endpoint' ) === 'ajax' ) {
			add_action( 'wp_ajax_nopriv_wcb_email', array( $this, 'wcb_email' ) );
			add_action( 'wp_ajax_wcb_email', array( $this, 'wcb_email' ) );
		} else {
			add_action( 'rest_api_init', array( $this, 'register_api' ) );
		}
		add_action( 'wp_ajax_nopriv_wcb_email', array( $this, 'wcb_email' ) );
		add_action( 'wp_ajax_wcb_email', array( $this, 'wcb_email' ) );
		add_action( 'wcb_schedule_add_recipient_to_list', array( $this, 'add_recipient_to_list' ), 10, 2 );
	}
	/**
	 * Register API json
	 */
	public function register_api() {
		/*Auto update plugins*/
		register_rest_route(
			'woocommerce_coupon_box', '/subscribe', array(
				'methods'  => 'POST',
				'callback' => array( $this, 'wcb_email' ),
			)
		);
	}
	public function add_recipient_to_list( $email, $list_id ) {
		$sendgrid = new VI_WOOCOMMERCE_COUPON_BOX_Admin_Sendgrid();
		$sendgrid->add_recipient_to_list( $email, $list_id );
	}

	/**
	 * Process ajax add email
	 */
	public function wcb_email() {
		if ( $this->settings->get_params( 'ajax_endpoint' ) === 'rest_api' ) {
			header( "Access-Control-Allow-Origin: *" );
			header( 'Access-Control-Allow-Methods: POST' );
		}
//		$secret = "";
//		$response = $_POST['g-recaptcha-response'];
//		$url='https://www.google.com/recaptcha/api/siteverify?secret='.$secret.'&response='.$response;
//		$curl       = curl_init();
//		curl_setopt_array( $curl, array(
//			CURLOPT_URL            => $url,
//			CURLOPT_RETURNTRANSFER => true,
//			CURLOPT_ENCODING       => "",
//			CURLOPT_MAXREDIRS      => 10,
//			CURLOPT_TIMEOUT        => 30,
//			CURLOPT_HTTP_VERSION   => CURL_HTTP_VERSION_1_1,
//			CURLOPT_CUSTOMREQUEST  => "POST",
//			CURLOPT_POSTFIELDS     => '{}',
//			CURLOPT_HTTPHEADER     => array(
//				"content-type: application/json"
//			),
//		) );
//
//		$response = curl_exec( $curl );
//		$err      = curl_error( $curl );
//		curl_close( $curl );
//		if ( $err ) {
//			echo "cURL Error #:" . $err;
//		} else {
//			$data = json_decode( $response );
//			print_r( $data );
//		}
		$language_ajax                   = isset( $_POST['language_ajax'] ) ? sanitize_text_field( $_POST['language_ajax'] ) : '';
		$wcb_enable_mailchimp            = $this->settings->get_params( 'wcb_enable_mailchimp' );
		$wcb_email_campaign              = $this->settings->get_params( 'wcb_email_campaign' );
		$wcb_footer_text_after_subscribe = $this->settings->get_params( 'wcb_footer_text_after_subscribe', $language_ajax );
		$email                           = filter_input( INPUT_POST, 'email', FILTER_SANITIZE_EMAIL );
		$msg                             = array(
			'status'           => '',
			'message'          => '',
			'warning'          => '',
			'code'             => '',
			'thankyou'         => '',
			'wcb_current_time' => current_time( 'timestamp', true ),
		);
		$meta                            = array(
			'coupon'              => '',
			'campaign'            => '',
			'mailchimp'           => '',
			'mailchimp_list'      => '',
			'activecampaign'      => '',
			'activecampaign_list' => '',
			'sendgrid'            => '',
			'sendgrid_list'       => '',
			'name'                => isset( $_POST['wcb_input_name'] ) ? sanitize_text_field( $_POST['wcb_input_name'] ) : '',
			'lname'               => isset( $_POST['wcb_input_lname'] ) ? sanitize_text_field( $_POST['wcb_input_lname'] ) : '',
			'mobile'              => isset( $_POST['wcb_input_mobile'] ) ? sanitize_text_field( $_POST['wcb_input_mobile'] ) : '',
			'birthday'            => isset( $_POST['wcb_input_birthday'] ) ? sanitize_text_field( $_POST['wcb_input_birthday'] ) : '',
			'gender'              => isset( $_POST['wcb_input_gender'] ) ? sanitize_text_field( $_POST['wcb_input_gender'] ) : '',
		);
		ob_start();
		?>
        <div class="wcb-footer-text-after-subscribe"><?php esc_html_e( $wcb_footer_text_after_subscribe ) ?></div>
		<?php
		$msg['thankyou'] = ob_get_clean();
		if ( is_email( $email ) ) {
//		    check if email already subscribed
			$emails_args = array(
				'post_type'      => 'wcb',
				'posts_per_page' => - 1,
				'title'          => $email,
				'post_status'    => array( // (string | array) - use post status. Retrieves posts by Post Status, default value i'publish'.
					'publish', // - a published post or page.
					'pending', // - post is pending review.
					'draft',  // - a post in draft status.
					'auto-draft', // - a newly created post, with no content.
					'future', // - a post to publish in the future.
					'private', // - not visible to users who are not logged in.
					'inherit', // - a revision. see get_children.
					'trash', // - post is in trashbin (available with Version 2.9).
				)
			);
			$the_query   = new WP_Query( $emails_args );
			if ( $the_query->have_posts() ) {
				$msg['status']  = 'existed';
				$msg['warning'] = esc_html__( '*This email already subscribed!', 'woocommerce-coupon-box' );
				wp_send_json( $msg );
				die;
			}
			wp_reset_postdata();
			// Create post object
			if ( $wcb_enable_mailchimp && class_exists( 'VI_WOOCOMMERCE_COUPON_BOX_Admin_Mailchimp' ) ) {
				/*Add mailchimp*/
				$mailchimp      = new VI_WOOCOMMERCE_COUPON_BOX_Admin_Mailchimp();
				$mailchimp_list = $this->settings->get_params( 'wcb_mlists' );
				if ( $mailchimp_list != 'non' ) {
					$mailchimp->add_email( $email, $meta['name'], $meta['lname'], $meta['mobile'] );
					$meta['mailchimp'] = $mailchimp_list;
				}
			}
			if ( $this->settings->get_params( 'wcb_enable_active_campaign' ) && class_exists( 'VI_WOOCOMMERCE_COUPON_BOXP_Admin_Active_Campaign' ) ) {
				$active_campaign      = new VI_WOOCOMMERCE_COUPON_BOXP_Admin_Active_Campaign();
				$active_campaign_list = $this->settings->get_params( 'wcb_active_campaign_list' );
				if ( $active_campaign_list ) {
					$active_campaign->contact_add( $email, $active_campaign_list, $meta['name'], $meta['lname'], $meta['mobile'] );
					$meta['activecampaign'] = $active_campaign_list;
				} else {
					$active_campaign->contact_add( $email, '', $meta['name'], '', $meta['mobile'] );
				}
			}
			if ( $this->settings->get_params( 'wcb_enable_sendgrid' ) && class_exists( 'VI_WOOCOMMERCE_COUPON_BOX_Admin_Sendgrid' ) ) {
				$sendgrid = new VI_WOOCOMMERCE_COUPON_BOX_Admin_Sendgrid();
				$sendgrid->add_recipient( $email, $meta['name'], $meta['lname'] );
				$sendgrid_list = $this->settings->get_params( 'wcb_sendgrid_list' );
				if ( $sendgrid_list && $sendgrid_list != 'none' ) {
					$meta['sendgrid'] = $sendgrid_list;
					$time             = time() + 60;
					wp_schedule_single_event(
						$time, 'wcb_schedule_add_recipient_to_list', array(
							$email,
							$sendgrid_list,
						)
					);
				}
			}
			$my_post = array(
				'post_title'  => $email,
				'post_type'   => 'wcb',
				'post_status' => 'publish',
			);
// Insert the post into the database
			$post_id    = wp_insert_post( $my_post );
			$uncategory = get_term_by( 'slug', 'uncategorized', 'wcb_email_campaign' );

			if ( $wcb_email_campaign ) {
				$my_post['tax_input'] = array(
					'wcb_email_campaign' => $wcb_email_campaign
				);
				$meta['campaign']     = $wcb_email_campaign;
				wp_set_post_terms( $post_id, array( $wcb_email_campaign ), 'wcb_email_campaign' );
			} elseif ( $uncategory ) {
				$term_id              = $uncategory->term_id;
				$my_post['tax_input'] = array(
					'wcb_email_campaign' => $term_id
				);
				$meta['campaign']     = $term_id;
				wp_set_post_terms( $post_id, array( $term_id ), 'wcb_email_campaign' );
			}
			$code           = $this->create_coupon( $email );
			$meta['coupon'] = $code;
			update_post_meta( $post_id, 'woo_coupon_box_meta', $meta );
			$msg['message'] = $this->settings->get_params( 'wcb_message_after_subscribe', $language_ajax );

			$coupon_select = $this->settings->get_params( 'wcb_coupon_select' );
			$show_coupon   = $this->settings->get_params( 'wcb_show_coupon' );
			if ( $coupon_select == 'non' ) {
				/*Only subscribe*/
				$this->send_email( $email, '', '', '', '', $language_ajax );
			} elseif ( in_array( $coupon_select, array( 'existing', 'unique' ) ) ) {
				/*Send a WooCommerce coupon*/
				if ( $code ) {
					$coupon = new WC_Coupon( $code );
					if ( $coupon->get_discount_type() == 'percent' ) {
						$coupon_value = $coupon->get_amount() . '%';
					} else {
						$coupon_value = $this->wc_price( $coupon->get_amount() );
					}
					$this->send_email( $email, '', strtoupper( trim( $coupon->get_code() ) ), $coupon->get_date_expires(), $coupon_value, $language_ajax );

					if ( $show_coupon ) {
						ob_start();
						?>
                        <div class="wcb-coupon-treasure-container">
                            <span><input type="text" readonly="readonly"
                                         value="<?php echo strtoupper( trim( $coupon->get_code() ) ); ?>"
                                         class="wcb-coupon-treasure"/></span>
                        </div>
                        <span class="wcb-guide">
						<?php esc_html_e( 'Enter this promo code at checkout page.', 'woocommerce-coupon-box' ) ?>
					</span>
						<?php
						$msg['code'] = ob_get_clean();
					}
				}

			} else {
				/*Send a custom coupon code*/
				$this->send_email( $email, '', $code, '', '', $language_ajax );
				if ( $show_coupon ) {
					ob_start();
					?>
                    <div class="wcb-coupon-treasure-container">
                        <span><input type="text" readonly="readonly" value="<?php echo $code; ?>"
                                     class="wcb-coupon-treasure"/></span>
                    </div>
                    <span class="wcb-guide">
						<?php esc_html_e( 'Enter this promo code at checkout page.', 'woocommerce-coupon-box' ) ?>
					</span>
					<?php
					$msg['code'] = ob_get_clean();
				}

			}
			$msg['status'] = 'subscribed';
			wp_send_json( $msg );
			die;
		} else {
			$msg['status']  = 'invalid';
			$msg['warning'] = esc_html__( '*Invalid email!', 'woocommerce-coupon-box' );
			wp_send_json( $msg );
			die;
		}
	}

	protected function rand() {
		if ( $this->characters_array === null ) {
			$this->characters_array = array_merge( range( 0, 9 ), range( 'a', 'z' ) );
		}
		$rand = rand( 0, count( $this->characters_array ) - 1 );

		return $this->characters_array[ $rand ];
	}

	protected function create_code() {
		wp_reset_postdata();

		$code = $this->settings->get_params( 'wcb_coupon_unique_prefix' );
		for ( $i = 0; $i < 6; $i ++ ) {
			$code .= $this->rand();
		}
		$args      = array(
			'post_type'      => 'shop_coupon',
			'post_status'    => 'publish',
			'posts_per_page' => - 1,
			'title'          => $code
		);
		$the_query = new WP_Query( $args );
		if ( $the_query->have_posts() ) {
			$code = $this->create_code();
		}
		wp_reset_postdata();

		return $code;
	}

	public function create_coupon( $email ) {
		$code = '';
		switch ( $this->settings->get_params( 'wcb_coupon_select' ) ) {
			case 'existing':
				$code = $this->settings->get_params( 'wcb_coupon' );
				if ( $this->settings->get_params( 'wcb_coupon_unique_email_restrictions' ) ) {
					$coupon = new WC_Coupon( $code );
					$er     = $coupon->get_email_restrictions();
					if ( ! in_array( $email, $er ) ) {
						$er[] = $email;
						$coupon->set_email_restrictions( $er );
						$coupon->save();
					}
				}
				break;
			case 'custom':
				$code = $this->settings->get_params( 'wcb_coupon_custom' );
				break;
			case 'unique':
				$code         = $this->create_code();
				$coupon       = new WC_Coupon( $code );
				$today        = strtotime( date( 'Ymd' ) );
				$date_expires = ( $this->settings->get_params( 'wcb_coupon_unique_date_expires' ) ) ? ( ( $this->settings->get_params( 'wcb_coupon_unique_date_expires' ) + 1 ) * 86400 + $today ) : '';
				$coupon->set_amount( $this->settings->get_params( 'wcb_coupon_unique_amount' ) );
				$coupon->set_date_expires( $date_expires );
				$coupon->set_discount_type( $this->settings->get_params( 'wcb_coupon_unique_discount_type' ) );
				$coupon->set_description( $this->settings->get_params( 'wcb_coupon_unique_description' ) );
				$coupon->set_individual_use( $this->settings->get_params( 'wcb_coupon_unique_individual_use' ) );
				if ( $this->settings->get_params( 'wcb_coupon_unique_product_ids' ) ) {
					$coupon->set_product_ids( implode( ',', array_filter( $this->settings->get_params( 'wcb_coupon_unique_product_ids' ) ) ) );
				}
				if ( $this->settings->get_params( 'wcb_coupon_unique_excluded_product_ids' ) ) {
					$coupon->set_excluded_product_ids( implode( ',', array_filter( $this->settings->get_params( 'wcb_coupon_unique_excluded_product_ids' ) ) ) );
				}
				$coupon->set_usage_limit( $this->settings->get_params( 'wcb_coupon_unique_usage_limit' ) );
				$coupon->set_usage_limit_per_user( $this->settings->get_params( 'wcb_coupon_unique_usage_limit_per_user' ) );
				$coupon->set_limit_usage_to_x_items( $this->settings->get_params( 'wcb_coupon_unique_limit_usage_to_x_items' ) );
				$coupon->set_free_shipping( $this->settings->get_params( 'wcb_coupon_unique_free_shipping' ) );
				$coupon->set_product_categories( $this->settings->get_params( 'wcb_coupon_unique_product_categories' ) );
				$coupon->set_excluded_product_categories( $this->settings->get_params( 'wcb_coupon_unique_excluded_product_categories' ) );
				$coupon->set_exclude_sale_items( $this->settings->get_params( 'wcb_coupon_unique_exclude_sale_items' ) );
				$coupon->set_minimum_amount( $this->settings->get_params( 'wcb_coupon_unique_minimum_amount' ) );
				$coupon->set_maximum_amount( $this->settings->get_params( 'wcb_coupon_unique_maximum_amount' ) );
				if ( $this->settings->get_params( 'wcb_coupon_unique_email_restrictions' ) ) {
					$coupon->set_email_restrictions( array( $email ) );
				}
				$coupon->save();
				$code = $coupon->get_code();
			default:
		}

		return $code;
	}

	public function send_email( $user_email, $customer_name, $coupon_code, $date_expires = '', $coupon_value = '', $language = '' ) {
		$button_shop_now = '<a href="' . ( $this->settings->get_params( 'wcb_button_shop_now_url' ) ? $this->settings->get_params( 'wcb_button_shop_now_url' ) : get_bloginfo( 'url' ) ) . '" target="_blank" style="text-decoration:none;display:inline-block;padding:10px 30px;margin:10px 0;font-size:' . $this->settings->get_params( 'wcb_button_shop_now_size' ) . 'px;color:' . $this->settings->get_params( 'wcb_button_shop_now_color' ) . ';background:' . $this->settings->get_params( 'wcb_button_shop_now_bg_color' ) . ';border-radius:' . $this->settings->get_params( 'wcb_button_shop_now_border_radius' ) . 'px">' . $this->settings->get_params( 'wcb_button_shop_now_title', $language ) . '</a>';
		$headers         = 'Content-Type: text/html';
		$content         = stripslashes( $this->settings->get_params( 'wcb_email_content', $language ) );
		$content         = str_replace( '{coupon_value}', $coupon_value, $content );
		$content         = str_replace( '{customer_name}', $customer_name, $content );
		$content         = str_replace( '{coupon_code}', '<span style="font-size: x-large;">' . strtoupper( $coupon_code ) . '</span>', $content );
		$content         = str_replace( '{date_expires}', empty( $date_expires ) ? esc_html__( 'never expires', 'woocommerce-coupon-box' ) : date( 'Y-m-d', strtotime( $date_expires ) ), $content );
		$content         = str_replace( '{last_valid_date}', empty( $date_expires ) ? '' : date( 'Y-m-d', strtotime( $date_expires ) - 86400 ), $content );
		$content         = str_replace( '{site_title}', get_bloginfo( 'name' ), $content );
		$content         = str_replace( '{shop_now}', $button_shop_now, $content );
		$subject         = stripslashes( $this->settings->get_params( 'wcb_email_subject', $language ) );
		$subject         = str_replace( '{coupon_value}', $coupon_value, $subject );
		$heading         = stripslashes( $this->settings->get_params( 'wcb_email_heading', $language ) );
		$heading         = str_replace( '{coupon_value}', $coupon_value, $heading );
		$mailer          = WC()->mailer();
		$email           = new WC_Email();
		$content         = $email->style_inline( $mailer->wrap_message( $heading, $content ) );
		$email->send( $user_email, $subject, $content, $headers, array() );
	}

	public function wc_price( $price, $args = array() ) {
		extract(
			apply_filters(
				'wc_price_args', wp_parse_args(
					$args, array(
						'ex_tax_label'       => false,
						'currency'           => get_option( 'woocommerce_currency' ),
						'decimal_separator'  => get_option( 'woocommerce_price_decimal_sep' ),
						'thousand_separator' => get_option( 'woocommerce_price_thousand_sep' ),
						'decimals'           => get_option( 'woocommerce_price_num_decimals', 2 ),
						'price_format'       => get_woocommerce_price_format(),
					)
				)
			)
		);
		$currency_pos = get_option( 'woocommerce_currency_pos' );
		$price_format = '%1$s%2$s';

		switch ( $currency_pos ) {
			case 'left' :
				$price_format = '%1$s%2$s';
				break;
			case 'right' :
				$price_format = '%2$s%1$s';
				break;
			case 'left_space' :
				$price_format = '%1$s&nbsp;%2$s';
				break;
			case 'right_space' :
				$price_format = '%2$s&nbsp;%1$s';
				break;
		}

		$negative = $price < 0;
		$price    = apply_filters( 'raw_woocommerce_price', floatval( $negative ? $price * - 1 : $price ) );
		$price    = apply_filters( 'formatted_woocommerce_price', number_format( $price, $decimals, $decimal_separator, $thousand_separator ), $price, $decimals, $decimal_separator, $thousand_separator );

		if ( apply_filters( 'woocommerce_price_trim_zeros', false ) && $decimals > 0 ) {
			$price = wc_trim_zeros( $price );
		}

		$formatted_price = ( $negative ? '-' : '' ) . sprintf( $price_format, $currency, $price );

		return $formatted_price;
	}

	public function woo_coupon_box_params_language( $language, $name ) {

		if ( in_array( $name, array(
			'wcb_title',
			'wcb_message',
			'wcb_message_after_subscribe',
			'wcb_button_text',
			'wcb_footer_text',
			'wcb_footer_text_after_subscribe',
			'wcb_gdpr_message',
			'wcb_follow_us',
			'wcb_email_subject',
			'wcb_email_heading',
			'wcb_email_content',
			'wcb_button_shop_now_title',
		) ) ) {
			$language = $this->language_ajax;
		}

		return $language;
	}

	/**
	 * Init Style and Script
	 */
	public function enqueue_scripts() {
		if ( is_admin() || is_customize_preview() ) {
			return;
		}
		if ( ! $this->settings->get_params( 'wcb_active' ) ) {
			return;
		}
		if ( $this->settings->get_params( 'wcb_multi_language' ) ) {
			if ( is_plugin_active( 'sitepress-multilingual-cms/sitepress.php' ) ) {
				$default_lang   = apply_filters( 'wpml_default_language', null );
				$this->language = apply_filters( 'wpml_current_language', null );
				if ( $this->language && $this->language !== $default_lang ) {
					$this->language_ajax = $this->language;
					add_filter( 'woo_coupon_box_params_language', array(
						$this,
						'woo_coupon_box_params_language'
					), 10, 2 );
				}
			} else if ( class_exists( 'Polylang' ) ) {
				$default_lang   = pll_default_language( 'slug' );
				$this->language = pll_current_language( 'slug' );
				if ( $this->language && $this->language !== $default_lang ) {
					$this->language_ajax = $this->language;
					add_filter( 'woo_coupon_box_params_language', array(
						$this,
						'woo_coupon_box_params_language'
					), 10, 2 );
				}
			}
		}
		if ( $this->settings->get_params( 'wcb_disable_login' ) && is_user_logged_in() ) {
			return;
		}
		if ( isset( $_COOKIE['woo_coupon_box'] ) ) {
			$cookies = explode( ':', $_COOKIE['woo_coupon_box'] );
			if ( isset( $cookies[0] ) && in_array( $cookies[0], array( 'subscribed', 'closed' ) ) ) {
				return;
			}
		}
		$wcb_assign_home = $this->settings->get_params( 'wcb_assign_home' );
		$logic_value     = $this->settings->get_params( 'wcb_assign' );

		if ( ! is_front_page() && $wcb_assign_home ) {
			return;
		}
		if ( $logic_value ) {
			if ( stristr( $logic_value, "return" ) === false ) {
				$logic_value = "return (" . $logic_value . ");";
			}
			if ( ! eval( $logic_value ) ) {
				return;
			}
		}
		$wcb_layout = $this->settings->get_params( 'wcb_layout' );

		$poup_type = $this->settings->get_params( 'wcb_popup_type' );
		if ( $poup_type ) {
			wp_enqueue_style( 'woocommerce-coupon-box-popup-type-' . $poup_type, VI_WOOCOMMERCE_COUPON_BOX_CSS . '/popup-effect/' . $poup_type . '.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
		}
		$wcb_effect = $this->settings->get_params( 'wcb_effect' );
		// script

		$wcb_popup_time = 0;
		if ( $this->settings->get_params( 'wcb_popup_time' ) ) {
			$wcb_popup_time_val = explode( ',', $this->settings->get_params( 'wcb_popup_time' ) );
			if ( count( $wcb_popup_time_val ) < 2 ) {
				$wcb_popup_time = absint( $wcb_popup_time_val[0] );
			} else {
				$wcb_popup_time = ( absint( $wcb_popup_time_val[0] ) > absint( $wcb_popup_time_val[1] ) ) ? rand( $wcb_popup_time_val[1], $wcb_popup_time_val[0] ) : rand( $wcb_popup_time_val[0], $wcb_popup_time_val[1] );
			}
		}
		$wcb_select_popup = $this->settings->get_params( 'wcb_select_popup' );
		if ( $wcb_select_popup == 'random' ) {
			$ran = rand( 1, 3 );
			if ( $ran == 1 ) {
				$wcb_select_popup = 'time';
			} elseif ( $ran == 2 ) {
				$wcb_select_popup = 'scroll';
			} else {
				$wcb_select_popup = 'exit';
			}
		}
		$wcb_expire = intval( $this->settings->get_params( 'wcb_expire' ) );
		switch ( $this->settings->get_params( 'wcb_expire_unit' ) ) {
			case 'day':
				$wcb_expire *= 86400;
				break;
			case 'hour':
				$wcb_expire *= 3600;
				break;
			case 'minute':
				$wcb_expire *= 60;
				break;
			default:
		}
		$data = array(
			'ajaxurl'            => $this->settings->get_params( 'ajax_endpoint' ) == 'ajax' ? ( admin_url( 'admin-ajax.php' ) . '?action=wcb_email' ) : site_url() . '/wp-json/woocommerce_coupon_box/subscribe',
			'wcb_select_popup'            => $wcb_select_popup,
			'wcb_popup_time'              => $wcb_popup_time,
			'wcb_popup_scroll'            => $this->settings->get_params( 'wcb_popup_scroll' ),
			'wcb_popup_exit'              => $this->settings->get_params( 'wcb_popup_exit' ),
			'wcb_on_close'                => $this->settings->get_params( 'wcb_on_close' ),
			'wcb_current_time'            => current_time( 'timestamp', true ),
			'wcb_show_coupon'             => $this->settings->get_params( 'wcb_show_coupon' ),
			'wcb_expire'                  => $wcb_expire,
			'wcb_expire_subscribed'       => intval( $this->settings->get_params( 'wcb_expire_subscribed' ) ) * 86400,
			'wcb_gdpr_checkbox'           => $this->settings->get_params( 'wcb_gdpr_checkbox' ),
			'wcb_popup_type'              => $this->settings->get_params( 'wcb_popup_type' ),
			'wcb_empty_email_warning'     => esc_html__( '*Please enter your email and subscribe.', 'woocommerce-coupon-box' ),
			'wcb_invalid_email_warning'   => esc_html__( '*Invalid email!', 'woocommerce-coupon-box' ),
			'wcb_title_after_subscribing' => esc_html__( 'Subscribed successfully!', 'woocommerce-coupon-box' ),
			'wcb_layout'                  => $wcb_layout,
			'wcb_popup_position'          => in_array( $this->settings->get_params( 'wcb_popup_icon_position' ), array(
					'top-left',
					'bottom-left'
				)
			) ? 'left' : 'right',
			'wcb_input_name'              => $this->settings->get_params( 'wcb_input_name' ),
			'wcb_input_name_required'     => $this->settings->get_params( 'wcb_input_name_required' ),
			'wcb_input_lname'             => $this->settings->get_params( 'wcb_input_lname' ),
			'wcb_input_lname_required'    => $this->settings->get_params( 'wcb_input_lname_required' ),
			'wcb_input_mobile'            => $this->settings->get_params( 'wcb_input_mobile' ),
			'wcb_input_mobile_required'   => $this->settings->get_params( 'wcb_input_mobile_required' ),
			'wcb_input_birthday'          => $this->settings->get_params( 'wcb_input_birthday' ),
			'wcb_input_birthday_required' => $this->settings->get_params( 'wcb_input_birthday_required' ),
			'wcb_input_gender'            => $this->settings->get_params( 'wcb_input_gender' ),
			'wcb_input_gender_required'   => $this->settings->get_params( 'wcb_input_gender_required' ),
			'language_ajax'               => $this->language_ajax,
		);
		if ( in_array( $wcb_effect, array( 'wcb-falling-leaves', 'wcb-falling-leaves-1', 'wcb-falling-heart' ) ) ) {
			wp_enqueue_style( 'wcb-falling-leaves-style', VI_WOOCOMMERCE_COUPON_BOX_CSS . 'wcb-falling-leaves.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
			wp_enqueue_script( 'wcb-falling-leaves-script', VI_WOOCOMMERCE_COUPON_BOX_JS . 'wcb-falling-leaves.js', array( 'jquery' ), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
			wp_localize_script( 'wcb-falling-leaves-script', 'wcb_params', $data );

		} elseif ( $wcb_effect == 'wcb-falling-snow' ) {
			wp_enqueue_style( 'wcb-falling-snow-style', VI_WOOCOMMERCE_COUPON_BOX_CSS . 'wcb-falling-snow.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
			wp_enqueue_script( 'wcb-falling-snow-script', VI_WOOCOMMERCE_COUPON_BOX_JS . 'wcb-falling-snow.js', array( 'jquery' ), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
			wp_localize_script( 'wcb-falling-snow-script', 'wcb_params', $data );
		} else {
			wp_enqueue_style( 'wcb-weather-style', VI_WOOCOMMERCE_COUPON_BOX_CSS . 'weather.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
			wp_enqueue_script( 'woocommerce-coupon-box-script', VI_WOOCOMMERCE_COUPON_BOX_JS . 'wcb.js', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION, true );

			wp_localize_script( 'woocommerce-coupon-box-script', 'wcb_params', $data );
		}
		switch ( $wcb_effect ) {
			case 'wcb-falling-leaves':
			case 'wcb-falling-leaves-1':
			case 'wcb-falling-heart':
				wp_enqueue_style( 'wcb-falling-leaves-style', VI_WOOCOMMERCE_COUPON_BOX_CSS . 'wcb-falling-leaves.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
				wp_enqueue_script( 'wcb-falling-leaves-script', VI_WOOCOMMERCE_COUPON_BOX_JS . 'wcb-falling-leaves.js', array( 'jquery' ), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
				wp_localize_script( 'wcb-falling-leaves-script', 'wcb_params', $data );
				break;
			case 'wcb-falling-snow':
				wp_enqueue_style( 'wcb-falling-snow-style', VI_WOOCOMMERCE_COUPON_BOX_CSS . 'wcb-falling-snow.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
				wp_enqueue_script( 'wcb-falling-snow-script', VI_WOOCOMMERCE_COUPON_BOX_JS . 'wcb-falling-snow.js', array( 'jquery' ), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
				wp_localize_script( 'wcb-falling-snow-script', 'wcb_params', $data );
				break;
			case 'wcb-snowflake':
			case 'wcb-snowflake-1':
				wp_enqueue_style( 'wcb-' . $wcb_effect . '-style', VI_WOOCOMMERCE_COUPON_BOX_CSS . $wcb_effect . '.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
				wp_enqueue_script( 'woocommerce-coupon-box-script', VI_WOOCOMMERCE_COUPON_BOX_JS . 'wcb.js', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION, true );
				wp_localize_script( 'woocommerce-coupon-box-script', 'wcb_params', $data );
				break;
			case 'wcb-snowflake-2-1':
			case 'wcb-snowflake-2-2':
			case 'wcb-snowflake-2-3':
				wp_enqueue_style( 'wcb-' . $wcb_effect . '-style', VI_WOOCOMMERCE_COUPON_BOX_CSS . 'snowflakes-2.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
				wp_enqueue_script( 'woocommerce-coupon-box-script', VI_WOOCOMMERCE_COUPON_BOX_JS . 'wcb.js', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION, true );
				wp_localize_script( 'woocommerce-coupon-box-script', 'wcb_params', $data );
				break;
			default:
				wp_enqueue_style( 'wcb-weather-style', VI_WOOCOMMERCE_COUPON_BOX_CSS . 'weather.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
				wp_enqueue_script( 'woocommerce-coupon-box-script', VI_WOOCOMMERCE_COUPON_BOX_JS . 'wcb.js', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION, true );
				wp_localize_script( 'woocommerce-coupon-box-script', 'wcb_params', $data );
		}
		wp_enqueue_style( 'wcb-snowflakes-style', VI_WOOCOMMERCE_COUPON_BOX_CSS . 'snowflakes.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
		wp_enqueue_style( 'wcb-snowflakes-1-style', VI_WOOCOMMERCE_COUPON_BOX_CSS . 'snowflakes-1.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
		wp_enqueue_style( 'wcb-snowflakes-2-style', VI_WOOCOMMERCE_COUPON_BOX_CSS . 'snowflakes-2.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
		add_action( 'wp_footer', array( $this, 'wp_footer' ) );


		if ( $wcb_layout > 0 && $wcb_layout < 6 ) {
			wp_enqueue_style( 'woocommerce-coupon-box-template-' . $wcb_layout, VI_WOOCOMMERCE_COUPON_BOX_CSS . 'layout-' . $wcb_layout . '.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
		}
		// style
		$header_font        = json_decode( $this->settings->get_params( 'wcb_header_font' ) );
		$header_font_f      = '';
		$header_font_handle = '';
		if ( $wcb_layout != 2 && isset( $header_font->font ) && $header_font->font ) {
			$header_font_f      = $header_font->font;
			$header_font_f      = str_replace( ' ', '+', $header_font_f );
			$src                = '//fonts.googleapis.com/css?family=' . $header_font_f . ':300,400,700';
			$header_font_handle = 'wcb-customizer-google-font-header-' . strtolower( str_replace( '+', '-', $header_font_f ) );
			wp_enqueue_style( $header_font_handle, $src );
			$css_inline = '.wcb-coupon-box .wcb-md-content .wcb-modal-header{font-family:' . $header_font->font . '}';
			wp_add_inline_style( $header_font_handle, $css_inline );
		}
		$body_font = json_decode( $this->settings->get_params( 'wcb_body_font' ) );
		if ( isset( $body_font->font ) && $body_font->font ) {

			$body_font_f = $body_font->font;
			$body_font_f = str_replace( ' ', '+', $body_font_f );
			if ( $body_font_f != $header_font_f ) {
				$src              = '//fonts.googleapis.com/css?family=' . $body_font_f . ':300,400,700';
				$body_font_handle = 'wcb-customizer-google-font-body-' . strtolower( str_replace( '+', '-', $body_font_f ) );
				wp_enqueue_style( $body_font_handle, $src );
				$css_inline = '.wcb-coupon-box .wcb-md-content .wcb-modal-body{font-family:' . $body_font->font . '}';
				wp_add_inline_style( $body_font_handle, $css_inline );
			} else {
				$css_inline = '.wcb-coupon-box .wcb-md-content .wcb-modal-body{font-family:' . $body_font->font . '}';
				wp_add_inline_style( $header_font_handle, $css_inline );
			}
		}
		wp_enqueue_style( 'woocommerce-coupon-box-giftbox-icons', VI_WOOCOMMERCE_COUPON_BOX_CSS . 'wcb_giftbox.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
		wp_enqueue_style( 'woocommerce-coupon-box-social-icons', VI_WOOCOMMERCE_COUPON_BOX_CSS . 'wcb_social_icons.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
		wp_enqueue_style( 'woocommerce-coupon-box-close-icons', VI_WOOCOMMERCE_COUPON_BOX_CSS . 'wcb_button_close_icons.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );
		wp_enqueue_style( 'woocommerce-coupon-box-basic', VI_WOOCOMMERCE_COUPON_BOX_CSS . 'basic.css', array(), VI_WOOCOMMERCE_COUPON_BOX_VERSION );

		$css                         = '';
		$wcb_button_close_position_x = $this->settings->get_params( 'wcb_button_close_position_x' ) * ( - 1 );
		$wcb_button_close_position_y = $this->settings->get_params( 'wcb_button_close_position_y' ) * ( - 1 );
		/*button close*/
		$css .= '.wcb-coupon-box span.wcb-md-close{';
		$css .= 'font-size:' . $this->settings->get_params( 'wcb_button_close_size' ) . 'px;';
		$css .= 'width:' . $this->settings->get_params( 'wcb_button_close_width' ) . 'px;';
		$css .= 'line-height:' . $this->settings->get_params( 'wcb_button_close_width' ) . 'px;';
		$css .= 'color:' . $this->settings->get_params( 'wcb_button_close_color' ) . ';';
		$css .= 'background:' . $this->settings->get_params( 'wcb_button_close_bg_color' ) . ';';
		$css .= 'border-radius:' . $this->settings->get_params( 'wcb_button_close_border_radius' ) . 'px;';
		$css .= 'right:' . $wcb_button_close_position_x . 'px;';
		$css .= 'top:' . $wcb_button_close_position_y . 'px;';
		$css .= '}';

		if ( $wcb_layout == 2 ) {
			/*coupon box border radius*/
			$css .= '.wcb-coupon-box .wcb-content-wrap .wcb-content-wrap-child{border-radius:' . $this->settings->get_params( 'wcb_border_radius' ) . 'px;}';

			/*right column*/
			$css .= '.wcb-coupon-box .wcb-content-wrap .wcb-md-content-right{';
			if ( $this->settings->get_params( 'wcb_right_column_bg' ) ) {
				$css .= 'background-color:' . $this->settings->get_params( 'wcb_right_column_bg' ) . ';';
			}
			if ( $this->settings->get_params( 'wcb_right_column_bg_img' ) ) {
				$css .= 'background-image:url(' . $this->settings->get_params( 'wcb_right_column_bg_img' ) . ');';
				$css .= 'background-repeat:' . $this->settings->get_params( 'wcb_right_column_bg_img_repeat' ) . ';';
				$css .= 'background-size:' . $this->settings->get_params( 'wcb_right_column_bg_img_size' ) . ';';
				$css .= 'background-position:' . $this->settings->get_params( 'wcb_right_column_bg_img_position' ) . ';';
			}
			$css .= '}';
		} elseif ( $wcb_layout == 5 ) {
			/*coupon box border radius*/
			$css .= '.wcb-coupon-box .wcb-content-wrap .wcb-content-wrap-child{border-radius:' . $this->settings->get_params( 'wcb_border_radius' ) . 'px;}';

			/*left column*/
			$css .= '.wcb-coupon-box .wcb-content-wrap .wcb-md-content-left{';
			if ( $this->settings->get_params( 'wcb_right_column_bg' ) ) {
				$css .= 'background-color:' . $this->settings->get_params( 'wcb_right_column_bg' ) . ';';
			}
			if ( $this->settings->get_params( 'wcb_right_column_bg_img' ) ) {
				$css .= 'background-image:url(' . $this->settings->get_params( 'wcb_right_column_bg_img' ) . ');';
				$css .= 'background-repeat:' . $this->settings->get_params( 'wcb_right_column_bg_img_repeat' ) . ';';
				$css .= 'background-size:' . $this->settings->get_params( 'wcb_right_column_bg_img_size' ) . ';';
				$css .= 'background-position:' . $this->settings->get_params( 'wcb_right_column_bg_img_position' ) . ';';
			}
			$css .= '}';

		} else {
			/*coupon box border radius*/
			$css .= '.wcb-coupon-box .wcb-content-wrap .wcb-md-content{border-radius:' . $this->settings->get_params( 'wcb_border_radius' ) . 'px;}';
		}
		/*header*/
		$css .= '.wcb-coupon-box .wcb-md-content .wcb-modal-header{';
		if ( $this->settings->get_params( 'wcb_bg_header' ) ) {
			$css .= 'background-color:' . $this->settings->get_params( 'wcb_bg_header' ) . ';';
		}
		if ( $this->settings->get_params( 'wcb_color_header' ) ) {
			$css .= 'color:' . $this->settings->get_params( 'wcb_color_header' ) . ';';
		}
		$css .= 'font-size:' . $this->settings->get_params( 'wcb_title_size' ) . 'px;';
		$css .= 'line-height:' . $this->settings->get_params( 'wcb_title_size' ) . 'px;';
		$css .= 'padding-top:' . $this->settings->get_params( 'wcb_title_space' ) . 'px;';
		$css .= 'padding-bottom:' . $this->settings->get_params( 'wcb_title_space' ) . 'px;';
		if ( $this->settings->get_params( 'wcb_header_bg_img' ) ) {
			$css .= 'background-image:url(' . $this->settings->get_params( 'wcb_header_bg_img' ) . ');';
			$css .= 'background-repeat:' . $this->settings->get_params( 'wcb_header_bg_img_repeat' ) . ';';
			$css .= 'background-size:' . $this->settings->get_params( 'wcb_header_bg_img_size' ) . ';';
			$css .= 'background-position:' . $this->settings->get_params( 'wcb_header_bg_img_position' ) . ';';
		}
		$css .= '}';

		/*body*/
		$css .= '.wcb-coupon-box .wcb-md-content .wcb-modal-body{';
		$css .= 'background-color:' . $this->settings->get_params( 'wcb_body_bg' ) . ';';
		$css .= 'color:' . $this->settings->get_params( 'wcb_body_text_color' ) . ';';
		if ( $this->settings->get_params( 'wcb_body_bg_img' ) ) {
			$css .= 'background-image:url(' . $this->settings->get_params( 'wcb_body_bg_img' ) . ');';
			$css .= 'background-repeat:' . $this->settings->get_params( 'wcb_body_bg_img_repeat' ) . ';';
			$css .= 'background-size:' . $this->settings->get_params( 'wcb_body_bg_img_size' ) . ';';
			$css .= 'background-position:' . $this->settings->get_params( 'wcb_body_bg_img_position' ) . ';';
		}
		$css .= '}';

		$css .= '.wcb-coupon-box .wcb-md-content .wcb-modal-body .wcb-coupon-message{color:' . $this->settings->get_params( 'wcb_color_message' ) . ';font-size:' . $this->settings->get_params( 'wcb_message_size' ) . 'px;text-align:' . $this->settings->get_params( 'wcb_message_align' ) . '}';

		/*text follow us*/
		$css .= $this->generate_css( '.wcb-coupon-box .wcb-md-content .wcb-text-title', 'color', 'wcb_color_follow_us', '', '' );
		/*email input*/
		$css .= '.wcb-coupon-box .wcb-newsletter input.wcb-email{';
		$css .= 'border-radius:' . $this->settings->get_params( 'wcb_email_input_border_radius' ) . 'px;';
		$css .= 'color:' . $this->settings->get_params( 'wcb_email_input_color' ) . ';';
		$css .= 'background:' . $this->settings->get_params( 'wcb_email_input_bg_color' ) . ';';
		$css .= '}';

		/*custom input fields*/
		$css .= '.wcb-coupon-box .wcb-custom-input-fields .wcb-input-field-item{border-radius:' . $this->settings->get_params( 'wcb_custom_input_border_radius' ) . 'px;}';
		$css .= '.wcb-coupon-box .wcb-custom-input-fields .wcb-input-field-item input,.wcb-coupon-box .wcb-custom-input-fields .wcb-input-field-item select{';
		$css .= 'color:' . $this->settings->get_params( 'wcb_custom_input_color' ) . ';';
		$css .= 'background:' . $this->settings->get_params( 'wcb_custom_input_bg_color' ) . ';';
		$css .= '}';
		$css .= '.wcb-coupon-box .wcb-modal-body .wcb-coupon-box-newsletter .wcb-newsletter-form input{margin-right:' . $this->settings->get_params( 'wcb_email_button_space' ) . 'px;}';

		if ( $this->settings->get_params( 'wcb_gdpr_checkbox' ) ) {
			$css .= '.wcb-coupon-box.wcb-collapse-after-close .wcb-coupon-box-newsletter{padding-bottom:0 !important;}';
		}
		/*button subscribe*/
		$css .= '.wcb-coupon-box .wcb-newsletter span.wcb-button{';
		$css .= 'color:' . $this->settings->get_params( 'wcb_button_text_color' ) . ';';
		$css .= 'background-color:' . $this->settings->get_params( 'wcb_button_bg_color' ) . ';';
		$css .= 'border-radius:' . $this->settings->get_params( 'wcb_button_border_radius' ) . 'px;';
		$css .= '}';
		/*overlay*/
		$css .= $this->generate_css( '.wcb-md-overlay', 'background', 'alpha_color_overlay', '', '' );
		/*social*/
		$css .= '.wcb-coupon-box .wcb-sharing-container .wcb-list-socials .wcb-social-icon{';
		$css .= 'font-size:' . $this->settings->get_params( 'wcb_social_icons_size' ) . 'px;';
		$css .= 'line-height:' . $this->settings->get_params( 'wcb_social_icons_size' ) . 'px;';
		$css .= '}';
		/*social-color*/
		$css .= $this->generate_css( '.wcb-coupon-box .wcb-sharing-container .wcb-list-socials .wcb-facebook-follow .wcb-social-icon', 'color', 'wcb_social_icons_facebook_color', '', '' );
		$css .= $this->generate_css( '.wcb-coupon-box .wcb-sharing-container .wcb-list-socials .wcb-twitter-follow .wcb-social-icon', 'color', 'wcb_social_icons_twitter_color', '', '' );
		$css .= $this->generate_css( '.wcb-coupon-box .wcb-sharing-container .wcb-list-socials .wcb-pinterest-follow .wcb-social-icon', 'color', 'wcb_social_icons_pinterest_color', '', '' );
		$css .= $this->generate_css( '.wcb-coupon-box .wcb-sharing-container .wcb-list-socials .wcb-instagram-follow .wcb-social-icon', 'color', 'wcb_social_icons_instagram_color', '', '' );
		$css .= $this->generate_css( '.wcb-coupon-box .wcb-sharing-container .wcb-list-socials .wcb-dribbble-follow .wcb-social-icon', 'color', 'wcb_social_icons_dribbble_color', '', '' );
		$css .= $this->generate_css( '.wcb-coupon-box .wcb-sharing-container .wcb-list-socials .wcb-tumblr-follow .wcb-social-icon', 'color', 'wcb_social_icons_tumblr_color', '', '' );
		$css .= $this->generate_css( '.wcb-coupon-box .wcb-sharing-container .wcb-list-socials .wcb-google-follow .wcb-social-icon', 'color', 'wcb_social_icons_google_color', '', '' );
		$css .= $this->generate_css( '.wcb-coupon-box .wcb-sharing-container .wcb-list-socials .wcb-vkontakte-follow .wcb-social-icon', 'color', 'wcb_social_icons_vkontakte_color', '', '' );
		$css .= $this->generate_css( '.wcb-coupon-box .wcb-sharing-container .wcb-list-socials .wcb-linkedin-follow .wcb-social-icon', 'color', 'wcb_social_icons_linkedin_color', '', '' );
		$css .= $this->generate_css( '.wcb-coupon-box .wcb-sharing-container .wcb-list-socials .wcb-youtube-follow .wcb-social-icon', 'color', 'wcb_social_icons_youtube_color', '', '' );
		$css .= $this->settings->get_params( 'wcb_custom_css' );
		/*popup icon*/
		$css .= '.wcb-coupon-box-small-icon{';
		$css .= 'font-size:' . $this->settings->get_params( 'wcb_popup_icon_size' ) . 'px;';
		$css .= 'line-height:' . $this->settings->get_params( 'wcb_popup_icon_size' ) . 'px;';
		$css .= 'color:' . $this->settings->get_params( 'wcb_popup_icon_color' ) . ';';
		$css .= '}';
		$css .= '.wcb-coupon-box-small-icon-wrap{';
		$css .= 'background-color:' . $this->settings->get_params( 'wcb_popup_icon_bg_color' ) . ';';
		$css .= 'border-radius:' . $this->settings->get_params( 'wcb_popup_icon_border_radius' ) . 'px;';
		$css .= '}';
		wp_add_inline_style( 'woocommerce-coupon-box-basic', $css );
//		wp_enqueue_script('woocommerce-coupon-box-google-recaptcha','https://www.google.com/recaptcha/api.js?render=6LeYiIUUAAAAAFCMXGY6gTCHiT_0BwRjPbQZtD7I');

	}

	public function generate_css( $selector, $style, $mod_name, $prefix = '', $postfix = '', $echo = false ) {
		$return = '';
		$mod    = $this->settings->get_params( $mod_name );
		if ( ! empty( $mod ) ) {
			$return = sprintf( '%s { %s:%s; }',
				$selector,
				$style,
				$prefix . $mod . $postfix
			);
			if ( $echo ) {
				echo $return;
			}
		}

		return $return;
	}

	/**
	 * Show HTML
	 */
	public function wp_footer() {
		echo $this->get_template( 'basic' );
		$hide = '';
		if ( ! $this->settings->get_params( 'wcb_popup_icon_mobile' ) ) {
			$hide = ' wcb-coupon-box-small-icon-hidden-mobile';
		}
		if ( $this->settings->get_params( 'wcb_popup_icon_enable' ) ) {
			if ( isset( $_COOKIE['woo_coupon_box'] ) ) {
				?>
                <div class="wcb-coupon-box-small-icon-wrap wcb-coupon-box-small-icon-position-<?php echo $this->settings->get_params( 'wcb_popup_icon_position' );
				echo $hide; ?>">
                    <div class="wcb-coupon-box-small-icon-container">
                        <span class="wcb-coupon-box-small-icon-close wcb_button_close_icons-cancel"
                              title="<?php esc_html_e( 'Do not show again', 'woocommerce-coupon-box' ) ?>"></span>
                        <span class="wcb-coupon-box-small-icon <?php echo $this->settings->get_params( 'wcb_popup_icon' ) ?>"></span>
                    </div>
                </div>
				<?php
			} else {
				if ( in_array( $this->settings->get_params( 'wcb_popup_icon_position' ), array(
					'top-left',
					'bottom-left'
				) ) ) {
					$hide .= ' wcb-coupon-box-small-icon-hide-left';
				} else {
					$hide .= ' wcb-coupon-box-small-icon-hide-right';
				}
				?>
                <div class="wcb-coupon-box-small-icon-wrap wcb-coupon-box-small-icon-position-<?php echo $this->settings->get_params( 'wcb_popup_icon_position' );
				echo $hide; ?>">
                    <div class="wcb-coupon-box-small-icon-container">
                        <span class="wcb-coupon-box-small-icon-close wcb_button_close_icons-cancel"
                              title="<?php esc_html_e( 'Do not show again', 'woocommerce-coupon-box' ) ?>"></span>
                        <span class="wcb-coupon-box-small-icon <?php echo $this->settings->get_params( 'wcb_popup_icon' ) ?>"></span>
                    </div>
                </div>
				<?php
			}
		}
	}

	/**
	 * Get template data
	 *
	 * @param $name
	 *
	 * @return string
	 */
	protected function get_template( $name ) {
		$title   = $this->settings->get_params( 'wcb_title' );
		$message = $this->settings->get_params( 'wcb_message' );
		$socials = $this->get_socials();

		$parten  = array(
			'/\{title\}/',
			'/\{message\}/',
			'/\{socials\}/'
		);
		$replace = array(
			esc_html( $title ),
			esc_html( $message ),
			ent2ncr( $socials )
		);

		ob_start();
		require_once VI_WOOCOMMERCE_COUPON_BOX_TEMPLATES . $name . '.php';
		$html = ob_get_clean();
		$html = preg_replace( $parten, $replace, $html );

		return ent2ncr( $html );
	}

	/**
	 * Get socials
	 */
	protected function get_socials() {
		$link_target = $this->settings->get_params( 'wcb_social_icons_target' );

		$facebook_url  = $this->settings->get_params( 'wcb_social_icons_facebook_url' );
		$twitter_url   = $this->settings->get_params( 'wcb_social_icons_twitter_url' );
		$pinterest_url = $this->settings->get_params( 'wcb_social_icons_pinterest_url' );
		$instagram_url = $this->settings->get_params( 'wcb_social_icons_instagram_url' );
		$dribbble_url  = $this->settings->get_params( 'wcb_social_icons_dribbble_url' );
		$tumblr_url    = $this->settings->get_params( 'wcb_social_icons_tumblr_url' );
		$google_url    = $this->settings->get_params( 'wcb_social_icons_google_url' );
		$vkontakte_url = $this->settings->get_params( 'wcb_social_icons_vkontakte_url' );
		$linkedin_url  = $this->settings->get_params( 'wcb_social_icons_linkedin_url' );
		$youtube_url   = $this->settings->get_params( 'wcb_social_icons_youtube_url' );

		$facebook_select  = $this->settings->get_params( 'wcb_social_icons_facebook_select' );
		$twitter_select   = $this->settings->get_params( 'wcb_social_icons_twitter_select' );
		$pinterest_select = $this->settings->get_params( 'wcb_social_icons_pinterest_select' );
		$instagram_select = $this->settings->get_params( 'wcb_social_icons_instagram_select' );
		$dribbble_select  = $this->settings->get_params( 'wcb_social_icons_dribbble_select' );
		$tumblr_select    = $this->settings->get_params( 'wcb_social_icons_tumblr_select' );
		$google_select    = $this->settings->get_params( 'wcb_social_icons_google_select' );
		$vkontakte_select = $this->settings->get_params( 'wcb_social_icons_vkontakte_select' );
		$linkedin_select  = $this->settings->get_params( 'wcb_social_icons_linkedin_select' );
		$youtube_select   = $this->settings->get_params( 'wcb_social_icons_youtube_select' );

		$html = '<ul class="wcb-list-socials wcb-list-unstyled" id="wcb-sharing-accounts">';

		if ( $facebook_url ) {
			ob_start();
			?>
            <a <?php if ( $link_target == '_blank' )
				esc_attr_e( 'target=_blank' ) ?> href="//www.facebook.com/<?php esc_attr_e( $facebook_url ) ?>"
                                                 class="wcb-social-button wcb-facebook"
                                                 title="<?php esc_html_e( 'Follow Facebook', 'woocommerce-coupon-box' ) ?>">
                <span class="wcb-social-icon <?php esc_attr_e( $facebook_select ) ?>"></span></a>
			<?php $facebook_html = ob_get_clean();

			$html .= '<li class="wcb-facebook-follow">' . $facebook_html . '</li>';
		}
		if ( $twitter_url ) {
			ob_start();
			?>
            <a <?php if ( $link_target == '_blank' )
				esc_attr_e( 'target=_blank' ) ?> href="//twitter.com/<?php esc_attr_e( $twitter_url ) ?>"
                                                 class="wcb-social-button wcb-twitter"
                                                 title="<?php esc_html_e( 'Follow Twitter', 'woocommerce-coupon-box' ) ?>">
                <span class="wcb-social-icon <?php esc_attr_e( $twitter_select ) ?>"></span>
            </a>
			<?php
			$twitter_html = ob_get_clean();
			$html         .= '<li class="wcb-twitter-follow">' . $twitter_html . '</li>';
		}
		if ( $pinterest_url ) {
			ob_start();
			?>
            <a <?php if ( $link_target == '_blank' )
				esc_attr_e( 'target=_blank' ) ?> href="//www.pinterest.com/<?php esc_attr_e( $pinterest_url ) ?>"
                                                 class="wcb-social-button wcb-pinterest"
                                                 title="<?php esc_html_e( 'Follow Pinterest', 'woocommerce-coupon-box' ) ?>">
                <span class="wcb-social-icon <?php esc_attr_e( $pinterest_select ) ?>"></span>
            </a>
			<?php
			$pinterest_html = ob_get_clean();
			$html           .= '<li class="wcb-pinterest-follow">' . $pinterest_html . '</li>';
		}
		if ( $instagram_url ) {
			ob_start();
			?>
            <a <?php if ( $link_target == '_blank' )
				esc_attr_e( 'target=_blank' ) ?> href="//www.instagram.com/<?php esc_attr_e( $instagram_url ) ?>"
                                                 class="wcb-social-button wcb-instagram"
                                                 title="<?php esc_html_e( 'Follow Instagram', 'woocommerce-coupon-box' ) ?>">
                <span class="wcb-social-icon <?php esc_attr_e( $instagram_select ) ?>"></span>
            </a>
			<?php
			$instagram_html = ob_get_clean();
			$html           .= '<li class="wcb-instagram-follow">' . $instagram_html . '</li>';
		}
		if ( $dribbble_url ) {
			ob_start();
			?>
            <a <?php if ( $link_target == '_blank' )
				esc_attr_e( 'target=_blank' ) ?> href="//dribbble.com/<?php esc_attr_e( $dribbble_url ) ?>"
                                                 class="wcb-social-button wcb-dribbble"
                                                 title="<?php esc_html_e( 'Follow Dribbble', 'woocommerce-coupon-box' ) ?>">
                <span class="wcb-social-icon <?php esc_attr_e( $dribbble_select ) ?>"></span>
            </a>
			<?php
			$dribbble_html = ob_get_clean();
			$html          .= '<li class="wcb-dribbble-follow">' . $dribbble_html . '</li>';
		}
		if ( $tumblr_url ) {
			ob_start();
			?>
            <a <?php if ( $link_target == '_blank' )
				esc_attr_e( 'target=_blank' ) ?> href="//www.tumblr.com/follow/<?php esc_attr_e( $tumblr_url ) ?>"
                                                 class="wcb-social-button wcb-tumblr"
                                                 title="<?php esc_html_e( 'Follow Tumblr', 'woocommerce-coupon-box' ) ?>">
                <span class="wcb-social-icon <?php esc_attr_e( $tumblr_select ) ?>"></span>
            </a>
			<?php
			$tumblr_html = ob_get_clean();
			$html        .= '<li class="wcb-tumblr-follow">' . $tumblr_html . '</li>';
		}
		if ( $google_url ) {
			ob_start();
			?>
            <a <?php if ( $link_target == '_blank' )
				esc_attr_e( 'target=_blank' ) ?> href="//plus.google.com/+<?php esc_attr_e( $google_url ) ?>"
                                                 class="wcb-social-button wcb-google-plus"
                                                 title="<?php esc_html_e( 'Follow Google Plus', 'woocommerce-coupon-box' ) ?>">
                <span class="wcb-social-icon <?php esc_attr_e( $google_select ) ?>"></span>
            </a>
			<?php
			$google_html = ob_get_clean();
			$html        .= '<li class="wcb-google-follow">' . $google_html . '</li>';
		}
		if ( $vkontakte_url ) {
			ob_start();
			?>
            <a <?php if ( $link_target == '_blank' )
				esc_attr_e( 'target=_blank' ) ?> href="//vk.com/<?php esc_attr_e( $vkontakte_url ) ?>"
                                                 class="wcb-social-button wcb-vk"
                                                 title="<?php esc_html_e( 'Follow VK', 'woocommerce-coupon-box' ) ?>">
                <span class="wcb-social-icon <?php esc_attr_e( $vkontakte_select ) ?>"></span>
            </a>
			<?php
			$vkontakte_html = ob_get_clean();
			$html           .= '<li class="wcb-vkontakte-follow">' . $vkontakte_html . '</li>';
		}
		if ( $linkedin_url ) {
			ob_start();
			?>
            <a <?php if ( $link_target == '_blank' )
				esc_attr_e( 'target=_blank' ) ?> href="//www.linkedin.com/in/<?php esc_attr_e( $linkedin_url ) ?>"
                                                 class="wcb-social-button wcb-linkedin"
                                                 title="<?php esc_html_e( 'Follow Linkedin', 'woocommerce-coupon-box' ) ?>">
                <span class="wcb-social-icon <?php esc_attr_e( $linkedin_select ) ?>"></span>
            </a>
			<?php
			$linkedin_html = ob_get_clean();
			$html          .= '<li class="wcb-linkedin-follow">' . $linkedin_html . '</li>';
		}

		if ( $youtube_url ) {
			ob_start();
			?>
            <a <?php if ( $link_target == '_blank' )
				esc_attr_e( 'target=_blank' ) ?> href="<?php echo esc_url_raw( $youtube_url ) ?>"
                                                 class="wcb-social-button wcb-youtube"
                                                 title="<?php esc_html_e( 'Follow Youtube', 'woocommerce-coupon-box' ) ?>">
                <span class="wcb-social-icon <?php esc_attr_e( $youtube_select ) ?>"></span>
            </a>
			<?php
			$youtube_html = ob_get_clean();
			$html         .= '<li class="wcb-youtube-follow">' . $youtube_html . '</li>';
		}

		$html = apply_filters( 'wcb_after_socials_html', $html );
		$html .= '</ul>';

		return $html;
	}

}