'use strict';
jQuery(document).ready(function ($) {

    let xr = $('.wcb-md-overlay').attr('class').split(' ');
    let leafContainer, leaves;
    if (xr.length > 1) {
        switch (xr[1]) {
            case 'wcb-falling-leaves':
                leafContainer = document.querySelector('.wcb-falling-leaves');
                    leaves = new LeafScene(leafContainer);
                leaves.init();
                leaves.render();
                $('.wcb-leaf-scene div').attr('class', '').addClass('wcb-falling-leaves-leaves');
                break;
            case 'wcb-falling-leaves-1':
                leafContainer = document.querySelector('.wcb-falling-leaves');
                    leaves = new LeafScene(leafContainer);
                leaves.init();
                leaves.render();
                $('.wcb-leaf-scene div').attr('class', '').addClass('wcb-falling-leaves-leaves-1');
                break;
            case 'wcb-falling-heart':
                leafContainer = document.querySelector('.wcb-falling-leaves');
                    leaves = new LeafScene(leafContainer);
                leaves.init();
                leaves.render();
                $('.wcb-leaf-scene div').attr('class', '').addClass('wcb-falling-leaves-heart');
                break;
            case 'wcb-falling-snow':
                Snowflake.init($('.wcb-falling-snow')[0]);
                break;
        }
    }
})
/*falling leaves effect*/
let LeafScene = function (el) {
    this.viewport = el;
    this.world = document.createElement('div');
    this.leaves = [];

    this.options = {
        numLeaves: 50,
        wind: {
            magnitude: 1.2,
            maxSpeed: 5,
            duration: 500,
            start: 0,
            speed: 0
        }
    };

    this.width = this.viewport.offsetWidth;
    this.height = this.viewport.offsetHeight;

    // animation helper
    this.timer = 0;

    this._resetLeaf = function (leaf) {

        // place leaf towards the top left
        leaf.x = this.width * 2 - Math.random() * this.width * 1.75;
        leaf.y = -10;
        leaf.z = Math.random() * 200;
        if (leaf.x > this.width) {
            leaf.x = this.width + 10;
            leaf.y = Math.random() * this.height / 2;
        }
        // at the start, the leaf can be anywhere
        if (this.timer == 0) {
            leaf.y = Math.random() * this.height;
        }

        // Choose axis of rotation.
        // If axis is not X, chose a random static x-rotation for greater letiability
        leaf.rotation.speed = Math.random() * 10;
        let randomAxis = Math.random();
        if (randomAxis > 0.5) {
            leaf.rotation.axis = 'X';
        } else if (randomAxis > 0.25) {
            leaf.rotation.axis = 'Y';
            leaf.rotation.x = Math.random() * 180 + 90;
        } else {
            leaf.rotation.axis = 'Z';
            leaf.rotation.x = Math.random() * 360 - 180;
            // looks weird if the rotation is too fast around this axis
            leaf.rotation.speed = Math.random() * 3;
        }

        // random speed
        leaf.xSpeedVariation = Math.random() * 0.8 - 0.4;
        leaf.ySpeed = Math.random() + 1.5;

        return leaf;
    }

    this._updateLeaf = function (leaf) {
        let leafWindSpeed = this.options.wind.speed(this.timer - this.options.wind.start, leaf.y);

        let xSpeed = leafWindSpeed + leaf.xSpeedVariation;
        leaf.x -= xSpeed;
        leaf.y += leaf.ySpeed;
        leaf.rotation.value += leaf.rotation.speed;

        let t = 'translateX( ' + leaf.x + 'px ) translateY( ' + leaf.y + 'px ) translateZ( ' + leaf.z + 'px )  rotate' + leaf.rotation.axis + '( ' + leaf.rotation.value + 'deg )';
        if (leaf.rotation.axis !== 'X') {
            t += ' rotateX(' + leaf.rotation.x + 'deg)';
        }
        leaf.el.style.webkitTransform = t;
        leaf.el.style.MozTransform = t;
        leaf.el.style.oTransform = t;
        leaf.el.style.transform = t;

        // reset if out of view
        if (leaf.x < -10 || leaf.y > this.height + 10) {
            this._resetLeaf(leaf);
        }
    }

    this._updateWind = function () {
        // wind follows a sine curve: asin(b*time + c) + a
        // where a = wind magnitude as a function of leaf position, b = wind.duration, c = offset
        // wind duration should be related to wind magnitude, e.g. higher windspeed means longer gust duration

        if (this.timer === 0 || this.timer > (this.options.wind.start + this.options.wind.duration)) {

            this.options.wind.magnitude = Math.random() * this.options.wind.maxSpeed;
            this.options.wind.duration = this.options.wind.magnitude * 50 + (Math.random() * 20 - 10);
            this.options.wind.start = this.timer;

            let screenHeight = this.height;

            this.options.wind.speed = function (t, y) {
                // should go from full wind speed at the top, to 1/2 speed at the bottom, using leaf Y
                let a = this.magnitude / 2 * (screenHeight - 2 * y / 3) / screenHeight;
                return a * Math.sin(2 * Math.PI / this.duration * t + (3 * Math.PI / 2)) + a;
            }
        }
    }
};

LeafScene.prototype.init = function () {

    for (let i = 0; i < this.options.numLeaves; i++) {
        let leaf = {
            el: document.createElement('div'),
            x: 0,
            y: 0,
            z: 0,
            rotation: {
                axis: 'X',
                value: 0,
                speed: 0,
                x: 0
            },
            xSpeedVariation: 0,
            ySpeed: 0,
            path: {
                type: 1,
                start: 0,

            },
            image: 1
        };
        this._resetLeaf(leaf);
        this.leaves.push(leaf);
        this.world.appendChild(leaf.el);
    }

    this.world.className = 'wcb-leaf-scene';
    this.viewport.appendChild(this.world);

    // set perspective
    this.world.style.webkitPerspective = "400px";
    this.world.style.MozPerspective = "400px";
    this.world.style.oPerspective = "400px";
    this.world.style.perspective = "400px";

    // reset window height/width on resize
    let self = this;
    window.onresize = function (event) {
        self.width = self.viewport.offsetWidth;
        self.height = self.viewport.offsetHeight;
    };
};

LeafScene.prototype.render = function () {
    this._updateWind();
    for (let i = 0; i < this.leaves.length; i++) {
        this._updateLeaf(this.leaves[i]);
    }

    this.timer++;

    requestAnimationFrame(this.render.bind(this));
};

/*falling snow effect*/

let Snowflake = (function () {

    let flakes;
    let flakesTotal = 250;
    let wind = 0;
    let mouseX;
    let mouseY;

    function Snowflake(size, x, y, vx, vy) {
        this.size = size;
        this.x = x;
        this.y = y;
        this.vx = vx;
        this.vy = vy;
        this.hit = false;
        this.melt = false;
        this.div = document.createElement('div');
        this.div.classList.add('wcb-snowflake');
        this.div.style.width = this.size + 'px';
        this.div.style.height = this.size + 'px';
    }

    Snowflake.prototype.move = function () {
        if (this.hit) {
            if (Math.random() > 0.995) this.melt = true;
        } else {
            this.x += this.vx + Math.min(Math.max(wind, -10), 10);
            this.y += this.vy;
        }

        // Wrap the snowflake to within the bounds of the page
        if (this.x > window.innerWidth + this.size) {
            this.x -= window.innerWidth + this.size;
        }

        if (this.x < -this.size) {
            this.x += window.innerWidth + this.size;
        }

        if (this.y > window.innerHeight + this.size) {
            this.x = Math.random() * window.innerWidth;
            this.y -= window.innerHeight + this.size * 2;
            this.melt = false;
        }

        let dx = mouseX - this.x;
        let dy = mouseY - this.y;
        this.hit = !this.melt && this.y < mouseY && dx * dx + dy * dy < 2400;
    };

    Snowflake.prototype.draw = function () {
        this.div.style.transform =
            this.div.style.MozTransform =
                this.div.style.webkitTransform =
                    'translate3d(' + this.x + 'px' + ',' + this.y + 'px,0)';
    };

    function update() {
        for (let i = flakes.length; i--;) {
            let flake = flakes[i];
            flake.move();
            flake.draw();
        }
        requestAnimationFrame(update);
    }

    Snowflake.init = function (container) {
        flakes = [];

        for (let i = flakesTotal; i--;) {
            let size = (Math.random() + 0.2) * 12 + 1;
            let flake = new Snowflake(
                size,
                Math.random() * window.innerWidth,
                Math.random() * window.innerHeight,
                Math.random() - 0.5,
                size * 0.3
            );
            container.appendChild(flake.div);
            flakes.push(flake);
        }

        container.onmousemove = function (event) {
            mouseX = event.clientX;
            mouseY = event.clientY;
            wind = (mouseX - window.innerWidth / 2) / window.innerWidth * 6;
        };

        container.ontouchstart = function (event) {
            mouseX = event.targetTouches[0].clientX;
            mouseY = event.targetTouches[0].clientY;
            event.preventDefault();
        };

        window.ondeviceorientation = function (event) {
            if (event) {
                wind = event.gamma / 10;
            }
        };

        update();
    };

    return Snowflake;

}());


(function ($) {
    wp.customize.bind('preview-ready', function () {
        wp.customize.preview.bind('active', function () {
            wp.customize.preview.send('wcb_update_language', woocommerce_coupon_box_design_params.language);
        })
    })
    let language_control=woocommerce_coupon_box_design_params.language_control;
    wp.customize('woo_coupon_box_params[wcb_layout]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box').removeClass('wcb-md-show').removeClass('wcb-current-layout');
            $('.wcb-coupon-box-' + newval).addClass('wcb-md-show').addClass('wcb-current-layout');
        });
    });
    /*Button close*/
    wp.customize('woo_coupon_box_params[wcb_button_close]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-md-close').attr('class', 'wcb-md-close ' + newval);
            $('.woo_coupon_box_params-wcb_button_close label').removeClass('wcb-radio-icons-active');
            $('.woo_coupon_box_params-wcb_button_close .' + newval).parent().addClass('wcb-radio-icons-active');
        });
    });
    wp.customize('woo_coupon_box_params[wcb_button_close_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-md-close').css({'color': newval});
        });
    });
    wp.customize('woo_coupon_box_params[wcb_button_close_bg_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-md-close').css({'background-color': newval});
        });
    });
    wp.customize('woo_coupon_box_params[wcb_button_close_size]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-md-close').css({'font-size': newval + 'px'});
        });
    });
    wp.customize('woo_coupon_box_params[wcb_button_close_width]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-md-close').css({'width': newval + 'px', 'line-height': newval + 'px'});
        });
    });
    wp.customize('woo_coupon_box_params[wcb_button_close_border_radius]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-md-close').css({'border-radius': newval + 'px'});
        });
    });
    wp.customize('woo_coupon_box_params[wcb_button_close_position_x]', function (value) {
        value.bind(function (newval) {
            newval = -newval;
            $('.wcb-coupon-box .wcb-md-close').css({'right': newval + 'px'});
        });
    });
    wp.customize('woo_coupon_box_params[wcb_button_close_position_y]', function (value) {
        value.bind(function (newval) {
            newval = -newval;
            $('.wcb-coupon-box .wcb-md-close').css({'top': newval + 'px'});
        });
    });

    wp.customize('woo_coupon_box_params[wcb_view_mode]', function (value) {
        value.bind(function (newval) {
            if (newval === '1') {
                $('.wcb-view-before-subscribe').show();
                $('.wcb-view-after-subscribe').hide();
            } else {
                $('.wcb-view-before-subscribe').hide();
                $('.wcb-view-after-subscribe').show();
            }
        });
    });

    wp.customize('woo_coupon_box_params[wcb_title'+language_control+']', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-header .wcb-coupon-box-title').html(newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_bg_header]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-header').css('backgroundColor', newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_header_bg_img]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-header').css('background-image', 'url(' + newval + ')');
        });
    });

    wp.customize('woo_coupon_box_params[wcb_header_bg_img_repeat]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-header').css('background-repeat', newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_header_bg_img_size]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-header').css('background-size', newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_header_bg_img_position]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-header').css('background-position', newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_color_header]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-header').css('color', newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_title_size]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-header').css({
                'font-size': newval + 'px',
                'line-height': newval + 'px'
            });
        });
    });
    wp.customize('woo_coupon_box_params[wcb_header_font]', function (value) {
        value.bind(function (newval) {
            let newData = JSON.parse(newval);
            let $font_f = newData.font;
            if ($font_f) {
                $font_f = $font_f.replace(/ /g, '+');
                let $src = '//fonts.googleapis.com/css?family=' + $font_f + ':300,400,700';
                $('<link rel="stylesheet" type="text/css" href="' + $src + '">').appendTo($('head'));
                $('#woocommerce-coupon-box-header-font').html('.wcb-coupon-box .wcb-modal-header{font-family:' + newData.font + ' !important;}');
            } else {
                $('#woocommerce-coupon-box-header-font').html('');
            }

        });
    });
    wp.customize('woo_coupon_box_params[wcb_body_font]', function (value) {
        value.bind(function (newval) {
            let newData = JSON.parse(newval);
            let $font_f = newData.font;
            if ($font_f) {
                $font_f = $font_f.replace(/ /g, '+');
                let $src = '//fonts.googleapis.com/css?family=' + $font_f + ':300,400,700';
                $('<link rel="stylesheet" type="text/css" href="' + $src + '">').appendTo($('head'));
                $('#woocommerce-coupon-box-body-font').html('.wcb-coupon-box .wcb-modal-body{font-family:' + newData.font + ' !important;}');
            } else {
                $('#woocommerce-coupon-box-body-font').html('');
            }
        });
    });

    wp.customize('woo_coupon_box_params[wcb_title_space]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-header').css({
                'padding-top': newval + 'px',
                'padding-bottom': newval + 'px'
            });
        });
    });

    wp.customize('woo_coupon_box_params[wcb_message'+language_control+']', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-coupon-message-before-subscribe').html(newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_border_radius]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box-1 .wcb-md-content').css({'border-radius': newval + 'px'});
            $('.wcb-coupon-box-2 .wcb-content-wrap-child').css({'border-radius': newval + 'px'});
            $('.wcb-coupon-box-3 .wcb-md-content').css({'border-radius': newval + 'px'});
            $('.wcb-coupon-box-4 .wcb-md-content').css({'border-radius': newval + 'px'});
            $('.wcb-coupon-box-5 .wcb-content-wrap-child').css({'border-radius': newval + 'px'});
        });
    });


    wp.customize('woo_coupon_box_params[wcb_message_after_subscribe'+language_control+']', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-coupon-message-after-subscribe').html(newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_message_size]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-body .wcb-coupon-message').css('font-size', newval + 'px');
        });
    });
    wp.customize('woo_coupon_box_params[wcb_color_message]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-body .wcb-coupon-message').css('color', newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_message_align]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-body .wcb-coupon-message').css('text-align', newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_body_bg]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-body').css('backgroundColor', newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_body_bg_img]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-body').css('background-image', 'url(' + newval + ')');
        });
    });


    wp.customize('woo_coupon_box_params[wcb_body_bg_img_repeat]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-body').css('background-repeat', newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_body_bg_img_size]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-body').css('background-size', newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_body_bg_img_position]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-body').css('background-position', newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_body_text_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-modal-body').css('color', newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_button_text'+language_control+']', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-newsletter span.wcb-button').html(newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_button_bg_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-newsletter span.wcb-button').css('backgroundColor', newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_button_border_radius]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-newsletter span.wcb-button').css('border-radius', newval + 'px');
        });
    });
    wp.customize('woo_coupon_box_params[wcb_email_input_border_radius]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-newsletter input.wcb-email').css('border-radius', newval + 'px');
        });
    });
    wp.customize('woo_coupon_box_params[wcb_email_input_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-newsletter input.wcb-email').css('color', newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_email_input_bg_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-newsletter input.wcb-email').css('background', newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_email_button_space]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-newsletter input.wcb-email').css('margin-right', newval + 'px');
        });
    });

    wp.customize('woo_coupon_box_params[wcb_button_text_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-newsletter span.wcb-button').css('color', newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_footer_text'+language_control+']', function (value) {
        value.bind(function (newval) {
            $('.wcb-footer-text').html(newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_footer_text_after_subscribe'+language_control+']', function (value) {
        value.bind(function (newval) {
            $('.wcb-footer-text-after-subscribe').html(newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_show_coupon]', function (value) {
        value.bind(function (newval) {
            if (newval) {
                $('.wcb-coupon-content').show();
            } else {
                $('.wcb-coupon-content').hide();
            }
        });
    });

    wp.customize('woo_coupon_box_params[wcb_gdpr_checkbox]', function (value) {
        value.bind(function (newval) {
            if (newval) {
                $('.wcb-gdpr-field').show();
            } else {
                $('.wcb-gdpr-field').hide();
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_gdpr_checkbox_checked]', function (value) {
        value.bind(function (newval) {
            if (newval) {
                $('.wcb-gdpr-checkbox').prop('checked', true);
            } else {
                $('.wcb-gdpr-checkbox').prop('checked', false);
            }
        });
    });

    wp.customize('woo_coupon_box_params[wcb_gdpr_message'+language_control+']', function (value) {
        value.bind(function (newval) {
            $('.wcb-gdpr-message').html(newval);
        });
    });

    wp.customize('woo_coupon_box_params[alpha_color_overlay]', function (value) {
        value.bind(function (newval) {
            $('body .wcb-md-overlay').css('background', newval);
        });
    });


    wp.customize('woo_coupon_box_params[wcb_popup_type]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box').map(function () {
                let xr=$(this).attr('class').split(' ');
                xr[3]=newval;
                $(this).attr('class',xr.join(' '));
            });
            $('.wcb-current-layout').removeClass('wcb-md-show');
            setTimeout(function () {
                $('.wcb-current-layout').addClass('wcb-md-show');
            }, 1000);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_color_follow_us]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-text-follow-us').css('color', newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_follow_us'+language_control+']', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-text-follow-us').html(newval);
        });
    });


    wp.customize('woo_coupon_box_params[wcb_countdown_number_color]', function (value) {
        value.bind(function (newval) {
            $('.counter-group .counter-block').css('color', newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_countdown_text_color]', function (value) {
        value.bind(function (newval) {
            $('.counter-group .counter-block .counter-caption').css('color', newval);
        });
    });

    /*image column for layout 2,5*/
    wp.customize('woo_coupon_box_params[wcb_right_column_bg]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-md-content-right').css('backgroundColor', newval);
            $('.wcb-coupon-box .wcb-md-content-left').css('backgroundColor', newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_right_column_bg_img]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-md-content-right').css('background-image', 'url(' + newval + ')');
            $('.wcb-coupon-box .wcb-md-content-left').css('background-image', 'url(' + newval + ')');
        });
    });


    wp.customize('woo_coupon_box_params[wcb_right_column_bg_img_repeat]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-md-content-right').css('background-repeat', newval);
            $('.wcb-coupon-box .wcb-md-content-left').css('background-repeat', newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_right_column_bg_img_size]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-md-content-right').css('background-size', newval);
            $('.wcb-coupon-box .wcb-md-content-left').css('background-size', newval);
        });
    });

    wp.customize('woo_coupon_box_params[wcb_right_column_bg_img_position]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box .wcb-md-content-right').css('background-position', newval);
            $('.wcb-coupon-box .wcb-md-content-left').css('background-position', newval);
        });
    });

    /*Social*/
    wp.customize('woo_coupon_box_params[wcb_social_icons_size]', function (value) {
        value.bind(function (newval) {
            $('.wcb-social-icon').css({'font-size': newval + 'px', 'line-height': newval + 'px'});
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_target]', function (value) {
        value.bind(function (newval) {
            $('.wcb-social-button').attr('target', newval);
        });
    });
    //facebook
    wp.customize('woo_coupon_box_params[wcb_social_icons_facebook_url]', function (value) {
        value.bind(function (newval) {
            $('.wcb-facebook-follow').attr('href', '//facebook.com/' + newval);
            if (newval) {
                $('.wcb-facebook-follow').show();
            } else {
                $('.wcb-facebook-follow').hide();
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_facebook_select]', function (value) {
        value.bind(function (newval) {
            $('.wcb-facebook-follow span').attr('class', 'wcb-social-icon ' + newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_facebook_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-facebook-follow span').css({'color': newval});
        });
    });

//twitter
    wp.customize('woo_coupon_box_params[wcb_social_icons_twitter_url]', function (value) {
        value.bind(function (newval) {
            $('.wcb-twitter-follow').attr('href', '//twitter.com/' + newval);
            if (newval) {
                $('.wcb-twitter-follow').show();
            } else {
                $('.wcb-twitter-follow').hide();
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_twitter_select]', function (value) {
        value.bind(function (newval) {
            $('.wcb-twitter-follow span').attr('class', 'wcb-social-icon ' + newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_twitter_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-twitter-follow span').css({'color': newval});
        });
    });
//pinterest
    wp.customize('woo_coupon_box_params[wcb_social_icons_pinterest_url]', function (value) {
        value.bind(function (newval) {
            $('.wcb-pinterest-follow').attr('href', '//pinterest.com/' + newval);
            if (newval) {
                $('.wcb-pinterest-follow').show();
            } else {
                $('.wcb-pinterest-follow').hide();
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_pinterest_select]', function (value) {
        value.bind(function (newval) {
            $('.wcb-pinterest-follow span').attr('class', 'wcb-social-icon ' + newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_pinterest_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-pinterest-follow span').css({'color': newval});
        });
    });
//instagram
    wp.customize('woo_coupon_box_params[wcb_social_icons_instagram_url]', function (value) {
        value.bind(function (newval) {
            $('.wcb-instagram-follow').attr('href', '//instagram.com/' + newval);
            if (newval) {
                $('.wcb-instagram-follow').show();
            } else {
                $('.wcb-instagram-follow').hide();
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_instagram_select]', function (value) {
        value.bind(function (newval) {
            $('.wcb-instagram-follow span').attr('class', 'wcb-social-icon ' + newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_instagram_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-instagram-follow span').css({'color': newval});
        });
    });
//dribbble
    wp.customize('woo_coupon_box_params[wcb_social_icons_dribbble_url]', function (value) {
        value.bind(function (newval) {
            $('.wcb-dribbble-follow').attr('href', '//dribbble.com/' + newval);
            if (newval) {
                $('.wcb-dribbble-follow').show();
            } else {
                $('.wcb-dribbble-follow').hide();
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_dribbble_select]', function (value) {
        value.bind(function (newval) {
            $('.wcb-dribbble-follow span').attr('class', 'wcb-social-icon ' + newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_dribbble_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-dribbble-follow span').css({'color': newval});
        });
    });
//tumblr
    wp.customize('woo_coupon_box_params[wcb_social_icons_tumblr_url]', function (value) {
        value.bind(function (newval) {
            $('.wcb-tumblr-follow').attr('href', '//tumblr.com/' + newval);
            if (newval) {
                $('.wcb-tumblr-follow').show();
            } else {
                $('.wcb-tumblr-follow').hide();
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_tumblr_select]', function (value) {
        value.bind(function (newval) {
            $('.wcb-tumblr-follow span').attr('class', 'wcb-social-icon ' + newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_tumblr_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-tumblr-follow span').css({'color': newval});
        });
    });
//google
    wp.customize('woo_coupon_box_params[wcb_social_icons_google_url]', function (value) {
        value.bind(function (newval) {
            $('.wcb-google-follow').attr('href', '//plus.google.com/' + newval);
            if (newval) {
                $('.wcb-google-follow').show();
            } else {
                $('.wcb-google-follow').hide();
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_google_select]', function (value) {
        value.bind(function (newval) {
            $('.wcb-google-follow span').attr('class', 'wcb-social-icon ' + newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_google_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-google-follow span').css({'color': newval});
        });
    });

    //vkontakte
    wp.customize('woo_coupon_box_params[wcb_social_icons_vkontakte_url]', function (value) {
        value.bind(function (newval) {
            $('.wcb-vkontakte-follow').attr('href', '//vk.com/' + newval);
            if (newval) {
                $('.wcb-vkontakte-follow').show();
            } else {
                $('.wcb-vkontakte-follow').hide();
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_vkontakte_select]', function (value) {
        value.bind(function (newval) {
            $('.wcb-vkontakte-follow span').attr('class', 'wcb-social-icon ' + newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_vkontakte_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-vkontakte-follow span').css({'color': newval});
        });
    });
//linkedin
    wp.customize('woo_coupon_box_params[wcb_social_icons_linkedin_url]', function (value) {
        value.bind(function (newval) {
            $('.wcb-linkedin-follow').attr('href', '//linkedin.com/in/' + newval);
            if (newval) {
                $('.wcb-linkedin-follow').show();
            } else {
                $('.wcb-linkedin-follow').hide();
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_linkedin_select]', function (value) {
        value.bind(function (newval) {
            $('.wcb-linkedin-follow span').attr('class', 'wcb-social-icon ' + newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_linkedin_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-linkedin-follow span').css({'color': newval});
        });
    });
//youtube
    wp.customize('woo_coupon_box_params[wcb_social_icons_youtube_url]', function (value) {
        value.bind(function (newval) {
            $('.wcb-youtube-follow').attr('href', newval);
            if (newval) {
                $('.wcb-youtube-follow').show();
            } else {
                $('.wcb-youtube-follow').hide();
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_youtube_select]', function (value) {
        value.bind(function (newval) {
            $('.wcb-youtube-follow span').attr('class', 'wcb-social-icon ' + newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_social_icons_youtube_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-youtube-follow span').css({'color': newval});
        });
    });

    wp.customize('woo_coupon_box_params[wcb_custom_css]', function (value) {
        value.bind(function (newval) {
            $('#woocommerce-coupon-box-custom-css').html(newval);
        });
    });
    /*popup icon*/
    wp.customize('woo_coupon_box_params[wcb_popup_icon]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box-small-icon').attr('class', 'wcb-coupon-box-small-icon ' + newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_popup_icon_enable]', function (value) {
        value.bind(function (newval) {
            if (newval) {
                if ($('.wcb-coupon-box-small-icon-wrap').hasClass('wcb-coupon-box-small-icon-position-bottom-left') || $('.wcb-coupon-box-small-icon-wrap').hasClass('wcb-coupon-box-small-icon-position-top-left')) {
                    $('.wcb-coupon-box-small-icon-wrap').removeClass('wcb-coupon-box-small-icon-hide-left');
                } else {
                    $('.wcb-coupon-box-small-icon-wrap').removeClass('wcb-coupon-box-small-icon-hide-right');
                }
            } else {
                if ($('.wcb-coupon-box-small-icon-wrap').hasClass('wcb-coupon-box-small-icon-position-bottom-left') || $('.wcb-coupon-box-small-icon-wrap').hasClass('wcb-coupon-box-small-icon-position-top-left')) {
                    $('.wcb-coupon-box-small-icon-wrap').addClass('wcb-coupon-box-small-icon-hide-left');
                } else {
                    $('.wcb-coupon-box-small-icon-wrap').addClass('wcb-coupon-box-small-icon-hide-right');
                }
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_popup_icon_position]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box-small-icon-wrap').removeClass('wcb-coupon-box-small-icon-position-top-right').removeClass('wcb-coupon-box-small-icon-position-bottom-right').removeClass('wcb-coupon-box-small-icon-position-top-left').removeClass('wcb-coupon-box-small-icon-position-bottom-left').addClass('wcb-coupon-box-small-icon-position-' + newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_popup_icon_mobile]', function (value) {
        value.bind(function (newval) {
            if (newval) {
                $('.wcb-coupon-box-small-icon-wrap').removeClass('wcb-coupon-box-small-icon-hidden-mobile');
            } else {
                $('.wcb-coupon-box-small-icon-wrap').addClass('wcb-coupon-box-small-icon-hidden-mobile');
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_popup_icon_size]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box-small-icon').css({'font-size': newval + 'px', 'line-height': newval + 'px'});
        });
    });
    wp.customize('woo_coupon_box_params[wcb_popup_icon_border_radius]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box-small-icon-wrap').css({'border-radius': newval + 'px'});
        });
    });
    wp.customize('woo_coupon_box_params[wcb_popup_icon_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box-small-icon').css('color', newval);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_popup_icon_bg_color]', function (value) {
        value.bind(function (newval) {
            $('.wcb-coupon-box-small-icon-wrap').css('background-color', newval);
        });
    });
    /*custom input fields*/

    wp.customize('woo_coupon_box_params[wcb_custom_input_border_radius]', function (value) {
        value.bind(function (newval) {
            $('#woocommerce-coupon-box-custom-input-border-radius').html('.wcb-coupon-box .wcb-content-wrap .wcb-custom-input-fields div.wcb-input-field-item{border-radius:' + newval + 'px;}');
        });
    });
    wp.customize('woo_coupon_box_params[wcb_custom_input_color]', function (value) {
        value.bind(function (newval) {
            $('#woocommerce-coupon-box-custom-input-color').html('.wcb-coupon-box .wcb-content-wrap .wcb-custom-input-fields div.wcb-input-field-item input,.wcb-coupon-box .wcb-content-wrap .wcb-custom-input-fields div.wcb-input-field-item select{color:' + newval + ';}');
        });
    });
    wp.customize('woo_coupon_box_params[wcb_custom_input_bg_color]', function (value) {
        value.bind(function (newval) {
            $('#woocommerce-coupon-box-custom-input-bg-color').html('.wcb-coupon-box .wcb-content-wrap .wcb-custom-input-fields div.wcb-input-field-item input,.wcb-coupon-box .wcb-content-wrap .wcb-custom-input-fields div.wcb-input-field-item select{background:' + newval + ';}');
        });
    });
    wp.customize('woo_coupon_box_params[wcb_input_name_required]', function (value) {
        value.bind(function (newval) {
            if (newval) {
                $('.wcb-input-name').attr('placeholder', 'Your first name(*)').attr('title', 'Your first name(*required)');
            } else {
                $('.wcb-input-name').attr('placeholder', 'Your first name').attr('title', 'Your first name');
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_input_lname_required]', function (value) {
        value.bind(function (newval) {
            if (newval) {
                $('.wcb-input-lname').attr('placeholder', 'Your last name(*)').attr('title', 'Your last name(*required)');
            } else {
                $('.wcb-input-lname').attr('placeholder', 'Your last name').attr('title', 'Your last name');
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_input_mobile_required]', function (value) {
        value.bind(function (newval) {
            if (newval) {
                $('.wcb-input-mobile').attr('placeholder', 'Your mobile(*)').attr('title', 'Your mobile(*required)');
            } else {
                $('.wcb-input-mobile').attr('placeholder', 'Your mobile').attr('title', 'Your mobile');
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_input_birthday_required]', function (value) {
        value.bind(function (newval) {
            if (newval) {
                $('.wcb-input-birthday').attr('placeholder', 'Your birthday(*)').attr('title', 'Your birthday(*required)');
            } else {
                $('.wcb-input-birthday').attr('placeholder', 'Your birthday').attr('title', 'Your birthday');
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_input_gender_required]', function (value) {
        value.bind(function (newval) {
            if (newval) {
                $('.wcb-input-gender').attr('title', 'Your gender(*required)').find('option').eq(0).html('Your gender(*)');
            } else {
                $('.wcb-input-gender').attr('title', 'Your gender').find('option').eq(0).html('Your gender');
            }
        });
    });
    wp.customize('woo_coupon_box_params[wcb_input_name]', function (value) {
        value.bind(function (newval) {
            let inputCount, returnHTML = '';
            if (newval) {
                inputCount = 1;
                returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-name">\n' +
                    '<input type="text" name="wcb_input_name" class="wcb-input-name" placeholder="Your first name" title="Your first name">\n' +
                    '</div>';
                if (wp.customize('woo_coupon_box_params[wcb_input_lname]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-lname">\n' +
                        '<input type="tel" name="wcb_input_lname" class="wcb-input-lname" placeholder="Your last name" title="Your last name">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_mobile]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-mobile">\n' +
                        '<input type="tel" name="wcb_input_mobile" class="wcb-input-mobile" placeholder="Your mobile" title="Your mobile">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_birthday]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-birthday">\n' +
                        '<input type="date" name="wcb_input_birthday" class="wcb-input-birthday" title="Your birthday">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_gender]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-gender">\n' +
                        '<select name="wcb_input_gender" class="wcb-input-gender" title="Your gender">\n' +
                        '<option>Your gender</option>\n' +
                        '<option value="male">Male</option>\n' +
                        '<option value="female">Female</option>\n' +
                        '<option value="other">Other</option>\n' +
                        '</select>\n' +
                        '</div>';
                }
            } else {
                inputCount = 0;
                if (wp.customize('woo_coupon_box_params[wcb_input_lname]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-lname">\n' +
                        '<input type="tel" name="wcb_input_lname" class="wcb-input-lname" placeholder="Your last name" title="Your last name">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_mobile]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-mobile">\n' +
                        '<input type="tel" name="wcb_input_mobile" class="wcb-input-mobile" placeholder="Your mobile" title="Your mobile">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_birthday]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-birthday">\n' +
                        '<input type="date" name="wcb_input_birthday" class="wcb-input-birthday" title="Your birthday">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_gender]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-gender">\n' +
                        '<select name="wcb_input_gender" class="wcb-input-gender" title="Your gender">\n' +
                        '<option>Your gender</option>\n' +
                        '<option value="male">Male</option>\n' +
                        '<option value="female">Female</option>\n' +
                        '<option value="other">Other</option>\n' +
                        '</select>\n' +
                        '</div>';
                }
            }
            $('.wcb-custom-input-fields').attr('class', 'wcb-custom-input-fields wcb-view-before-subscribe ' + 'wcb-input-fields-count-' + inputCount).html(returnHTML);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_input_lname]', function (value) {
        value.bind(function (newval) {
            let inputCount, returnHTML = '';
            if (newval) {
                inputCount = 1;
                if (wp.customize('woo_coupon_box_params[wcb_input_name]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-name">\n' +
                        '<input type="tel" name="wcb_input_name" class="wcb-input-name" placeholder="Your first name" title="Your first name">\n' +
                        '</div>';
                }
                returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-lname">\n' +
                    '<input type="text" name="wcb_input_lname" class="wcb-input-lname" placeholder="Your last name" title="Your last name">\n' +
                    '</div>';

                if (wp.customize('woo_coupon_box_params[wcb_input_mobile]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-mobile">\n' +
                        '<input type="tel" name="wcb_input_mobile" class="wcb-input-mobile" placeholder="Your mobile" title="Your mobile">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_birthday]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-birthday">\n' +
                        '<input type="date" name="wcb_input_birthday" class="wcb-input-birthday" title="Your birthday">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_gender]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-gender">\n' +
                        '<select name="wcb_input_gender" class="wcb-input-gender" title="Your gender">\n' +
                        '<option>Your gender</option>\n' +
                        '<option value="male">Male</option>\n' +
                        '<option value="female">Female</option>\n' +
                        '<option value="other">Other</option>\n' +
                        '</select>\n' +
                        '</div>';
                }
            } else {
                inputCount = 0;
                if (wp.customize('woo_coupon_box_params[wcb_input_name]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-name">\n' +
                        '<input type="tel" name="wcb_input_name" class="wcb-input-name" placeholder="Your first name" title="Your first name">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_mobile]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-mobile">\n' +
                        '<input type="tel" name="wcb_input_mobile" class="wcb-input-mobile" placeholder="Your mobile" title="Your mobile">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_birthday]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-birthday">\n' +
                        '<input type="date" name="wcb_input_birthday" class="wcb-input-birthday" title="Your birthday">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_gender]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-gender">\n' +
                        '<select name="wcb_input_gender" class="wcb-input-gender" title="Your gender">\n' +
                        '<option>Your gender</option>\n' +
                        '<option value="male">Male</option>\n' +
                        '<option value="female">Female</option>\n' +
                        '<option value="other">Other</option>\n' +
                        '</select>\n' +
                        '</div>';
                }
            }
            $('.wcb-custom-input-fields').attr('class', 'wcb-custom-input-fields wcb-view-before-subscribe ' + 'wcb-input-fields-count-' + inputCount).html(returnHTML);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_input_mobile]', function (value) {
        value.bind(function (newval) {
            let inputCount, returnHTML = '';
            if (newval) {
                inputCount = 1;

                if (wp.customize('woo_coupon_box_params[wcb_input_name]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-name">\n' +
                        '<input type="text" name="wcb_input_name" class="wcb-input-name" placeholder="Your first name" title="Your first name">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_lname]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-lname">\n' +
                        '<input type="tel" name="wcb_input_lname" class="wcb-input-lname" placeholder="Your last name" title="Your last name">\n' +
                        '</div>';
                }
                returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-mobile">\n' +
                    '<input type="tel" name="wcb_input_mobile" class="wcb-input-mobile" placeholder="Your mobile" title="Your mobile">\n' +
                    '</div>';
                if (wp.customize('woo_coupon_box_params[wcb_input_birthday]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-birthday">\n' +
                        '<input type="date" name="wcb_input_birthday" class="wcb-input-birthday" title="Your birthday">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_gender]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-gender">\n' +
                        '<select name="wcb_input_gender" class="wcb-input-gender" title="Your gender">\n' +
                        '<option>Your gender</option>\n' +
                        '<option value="male">Male</option>\n' +
                        '<option value="female">Female</option>\n' +
                        '<option value="other">Other</option>\n' +
                        '</select>\n' +
                        '</div>';
                }
            } else {
                inputCount = 0;
                if (wp.customize('woo_coupon_box_params[wcb_input_name]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-name">\n' +
                        '<input type="text" name="wcb_input_name" class="wcb-input-name" placeholder="Your first name" title="Your first name">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_lname]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-lname">\n' +
                        '<input type="tel" name="wcb_input_lname" class="wcb-input-lname" placeholder="Your last name" title="Your last name">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_birthday]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-birthday">\n' +
                        '<input type="date" name="wcb_input_birthday" class="wcb-input-birthday" title="Your birthday">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_gender]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-gender">\n' +
                        '<select name="wcb_input_gender" class="wcb-input-gender" title="Your gender">\n' +
                        '<option>Your gender</option>\n' +
                        '<option value="male">Male</option>\n' +
                        '<option value="female">Female</option>\n' +
                        '<option value="other">Other</option>\n' +
                        '</select>\n' +
                        '</div>';
                }
            }
            $('.wcb-custom-input-fields').attr('class', 'wcb-custom-input-fields wcb-view-before-subscribe ' + 'wcb-input-fields-count-' + inputCount).html(returnHTML);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_input_birthday]', function (value) {
        value.bind(function (newval) {
            let inputCount, returnHTML = '';
            if (newval) {
                inputCount = 1;
                if (wp.customize('woo_coupon_box_params[wcb_input_name]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-name">\n' +
                        '<input type="text" name="wcb_input_name" class="wcb-input-name" placeholder="Your first name" title="Your first name">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_lname]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-lname">\n' +
                        '<input type="tel" name="wcb_input_lname" class="wcb-input-lname" placeholder="Your last name" title="Your last name">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_mobile]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-mobile">\n' +
                        '<input type="tel" name="wcb_input_mobile" class="wcb-input-mobile" placeholder="Your mobile" title="Your mobile">\n' +
                        '</div>';
                }

                returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-birthday">\n' +
                    '<input type="date" name="wcb_input_birthday" class="wcb-input-birthday" title="Your birthday">\n' +
                    '</div>';
                if (wp.customize('woo_coupon_box_params[wcb_input_gender]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-gender">\n' +
                        '<select name="wcb_input_gender" class="wcb-input-gender" title="Your gender">\n' +
                        '<option>Your gender</option>\n' +
                        '<option value="male">Male</option>\n' +
                        '<option value="female">Female</option>\n' +
                        '<option value="other">Other</option>\n' +
                        '</select>\n' +
                        '</div>';
                }
            } else {
                inputCount = 0;
                if (wp.customize('woo_coupon_box_params[wcb_input_name]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-name">\n' +
                        '<input type="text" name="wcb_input_name" class="wcb-input-name" placeholder="Your first name" title="Your first name">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_lname]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-lname">\n' +
                        '<input type="tel" name="wcb_input_lname" class="wcb-input-lname" placeholder="Your last name" title="Your last name">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_mobile]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-mobile">\n' +
                        '<input type="tel" name="wcb_input_mobile" class="wcb-input-mobile" placeholder="Your mobile" title="Your mobile">\n' +
                        '</div>';
                }

                if (wp.customize('woo_coupon_box_params[wcb_input_gender]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-gender">\n' +
                        '<select name="wcb_input_gender" class="wcb-input-gender" title="Your gender">\n' +
                        '<option>Your gender</option>\n' +
                        '<option value="male">Male</option>\n' +
                        '<option value="female">Female</option>\n' +
                        '<option value="other">Other</option>\n' +
                        '</select>\n' +
                        '</div>';
                }
            }
            $('.wcb-custom-input-fields').attr('class', 'wcb-custom-input-fields wcb-view-before-subscribe ' + 'wcb-input-fields-count-' + inputCount).html(returnHTML);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_input_gender]', function (value) {
        value.bind(function (newval) {
            let inputCount, returnHTML = '';
            if (newval) {
                inputCount = 1;
                if (wp.customize('woo_coupon_box_params[wcb_input_name]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-name">\n' +
                        '<input type="text" name="wcb_input_name" class="wcb-input-name" placeholder="Your first name" title="Your first name">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_lname]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-lname">\n' +
                        '<input type="tel" name="wcb_input_lname" class="wcb-input-lname" placeholder="Your last name" title="Your last name">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_mobile]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-mobile">\n' +
                        '<input type="tel" name="wcb_input_mobile" class="wcb-input-mobile" placeholder="Your mobile" title="Your mobile">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_birthday]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-birthday">\n' +
                        '<input type="date" name="wcb_input_birthday" class="wcb-input-birthday" title="Your birthday">\n' +
                        '</div>';
                }
                returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-gender">\n' +
                    '<select name="wcb_input_gender" class="wcb-input-gender" title="Your gender">\n' +
                    '<option>Your gender</option>\n' +
                    '<option value="male">Male</option>\n' +
                    '<option value="female">Female</option>\n' +
                    '<option value="other">Other</option>\n' +
                    '</select>\n' +
                    '</div>';
            } else {
                inputCount = 0;
                if (wp.customize('woo_coupon_box_params[wcb_input_name]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-name">\n' +
                        '<input type="text" name="wcb_input_name" class="wcb-input-name" placeholder="Your first name" title="Your first name">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_lname]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-lname">\n' +
                        '<input type="tel" name="wcb_input_lname" class="wcb-input-lname" placeholder="Your last name" title="Your last name">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_mobile]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-mobile">\n' +
                        '<input type="tel" name="wcb_input_mobile" class="wcb-input-mobile" placeholder="Your mobile" title="Your mobile">\n' +
                        '</div>';
                }
                if (wp.customize('woo_coupon_box_params[wcb_input_birthday]').get()) {
                    inputCount++;
                    returnHTML += '<div class="wcb-input-field-item wcb-input-field-item-birthday">\n' +
                        '<input type="date" name="wcb_input_birthday" class="wcb-input-birthday" title="Your birthday">\n' +
                        '</div>';
                }

            }
            $('.wcb-custom-input-fields').attr('class', 'wcb-custom-input-fields wcb-view-before-subscribe ' + 'wcb-input-fields-count-' + inputCount).html(returnHTML);
        });
    });
    wp.customize('woo_coupon_box_params[wcb_effect]', function (value) {
        value.bind(function (newval) {
            let xr = $('.wcb-md-overlay').attr('class').split(' '),
                leafContainer,
                leaves;
            if (!newval) {
                $('.wcb-md-overlay').removeClass(xr[1]).html('');
            } else {
                switch (newval) {
                    case 'wcb-falling-leaves':
                        $('.wcb-md-overlay').removeClass(xr[1]).html('').addClass('wcb-falling-leaves');
                        leafContainer = document.querySelector('.wcb-falling-leaves'),
                            leaves = new LeafScene(leafContainer);
                        leaves.init();
                        leaves.render();
                        $('.wcb-leaf-scene div').attr('class', '').addClass('wcb-falling-leaves-leaves');
                        break;
                    case 'wcb-falling-leaves-1':
                        $('.wcb-md-overlay').removeClass(xr[1]).html('').addClass('wcb-falling-leaves');
                        leafContainer = document.querySelector('.wcb-falling-leaves'),
                            leaves = new LeafScene(leafContainer);
                        leaves.init();
                        leaves.render();
                        $('.wcb-leaf-scene div').attr('class', '').addClass('wcb-falling-leaves-leaves-1');
                        break;
                    case 'wcb-falling-heart':
                        $('.wcb-md-overlay').removeClass(xr[1]).html('').addClass('wcb-falling-leaves');
                        leafContainer = document.querySelector('.wcb-falling-leaves'),
                            leaves = new LeafScene(leafContainer);
                        leaves.init();
                        leaves.render();
                        $('.wcb-leaf-scene div').attr('class', '').addClass('wcb-falling-leaves-heart');
                        break;
                    case 'wcb-falling-snow':
                        $('.wcb-md-overlay').removeClass(xr[1]).html('').addClass(newval);
                        Snowflake.init($('.wcb-falling-snow')[0]);
                        break;
                    case 'wcb-falling-snow-1':
                        $('.wcb-md-overlay').removeClass(xr[1]).html('<div class="wcb-weather wcb-weather-snow"></div>');
                        break;
                    case 'wcb-falling-rain':
                        $('.wcb-md-overlay').removeClass(xr[1]).html('<div class="wcb-weather wcb-weather-rain"></div>');
                        break;
                    case 'snowflakes':
                        $('.wcb-md-overlay').removeClass(xr[1]).html('<div class="wcb-background-effect-snowflakes" aria-hidden="true">\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❅\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❅\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❆\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❄\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❅\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❆\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❄\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❅\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❆\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❄\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❅\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❅\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❆\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❄\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❅\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❆\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❄\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❅\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❆\n' +
                            '                </div>\n' +
                            '                <div class="wcb-background-effect-snowflake">\n' +
                            '                    ❄\n' +
                            '                </div>\n' +
                            '            </div>');
                        break;

                    case 'snowflakes-1':
                        $('.wcb-md-overlay').removeClass(xr[1]).html('<div class="wcb-background-effect-snowflakes-1" aria-hidden="true">\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '                <span></span>\n' +
                            '            </div>');
                        break;
                    case 'snowflakes-2-1':
                    case 'snowflakes-2-2':
                    case 'snowflakes-2-3':
                        $('.wcb-md-overlay').attr('class','wcb-md-overlay wcb-background-effect-snowflakes-2 wcb-background-effect-'+newval).html('<i></i>');
                        break;
                }
            }
        });
    });

})($);
